@@ -11,7 +11,7 @@ end
 --]]
 function atk_corvette.atk( target, dokill )
    target = atk.com_think( target, dokill )
-   if target == nil then return end
+   if target==nil then return end
 
    -- Targeting stuff
    ai.hostile(target) -- Mark as hostile
@@ -36,7 +36,7 @@ function atk_corvette.atk( target, dokill )
    -- Close enough to melee
    -- TODO: Corvette-specific attack functions.
    else
-      if target:stats().mass < 500 then
+      if target:mass() < 500 then
         atk.space_sup( target, dist )
       else
         mem.aggressive = true
