@@ -93,9 +93,8 @@ local function __zigzag_run_decide( self, target )
    -- Some AI will not do fancy maneuvers
    if mem.simplecombat then return false end
    -- Try to figure it out
-   local ss = self:stats()
-   local relspe = ss.speed_max/target:stats().speed_max
-   return ( ss.mass <= 400
+   local relspe = self:speedMax() / target:speedMax()
+   return ( self:mass() <= 400
             and relspe <= 1.01
             and ai.hasprojectile()
             and (not ai.hasafterburner() or self:energy() < 10)
@@ -194,7 +193,7 @@ end
 
 
 --[[
--- Lunges towards the target always thrusting
+-- Lunges towards the target always accelerating
 --]]
 function lunge( target )
    if not target:exists() then
@@ -404,7 +403,7 @@ function __choose_land_target ( target )
    return target
 end
 
-function land ( target )
+function land( target )
    local planet = __choose_land_target ( target )
    ai.pushsubtask( "_landgo", planet )
 end
@@ -610,7 +609,7 @@ function _run_hyp( data )
          local dir = ai.dir(jp_pos)
          __zigzag(dir, math.rad(70))
       else
-         if jdist > 3*bdist and plt:stats().mass < 600 then
+         if jdist > 3*bdist and plt:mass() < 600 then
             jdir = ai.careful_face(jp_pos)
          else --Heavy ships should rush to jump point
             jdir = ai.face( jp_pos, nil, true )
@@ -734,8 +733,9 @@ function hyperspace( target )
          ai.poptask()
          return
       else
-         -- Push the new task
-         ai.pushsubtask("hyperspace", target)
+         -- Switch to a new task with the target
+         ai.poptask()
+         ai.pushtask("hyperspace", target)
          return
       end
    end
@@ -743,15 +743,26 @@ function hyperspace( target )
    ai.pushsubtask( "_hyp_approach", target )
 end
 
+-- luacheck: globals hyperspace_follow (AI Task functions passed by name)
+function hyperspace_follow( target )
+   mem.target_bias = vec2.newP( rnd.rnd()*target:radius()/2, rnd.angle() )
+   ai.pushsubtask( "_hyp_approach_follow", target )
+end
+
 -- luacheck: globals _hyp_approach (AI Task functions passed by name)
 function _hyp_approach( target )
    __hyp_approach( target )
 end
-function __hyp_approach( target )
+-- luacheck: globals _hyp_approach_follow (AI Task functions passed by name)
+function _hyp_approach_follow( target )
+   __hyp_approach( target, "_hyp_jump_follow" )
+end
+function __hyp_approach( target, jumptsk )
    local dir
    local pos      = target:pos() + mem.target_bias
    local dist     = ai.dist( pos )
    local bdist    = ai.minbrakedist()
+   jumptsk  = jumptsk or "_hyp_jump"
 
    -- 2 methods for dir
    if not mem.careful or dist < 3*bdist then
@@ -766,9 +777,9 @@ function __hyp_approach( target )
    -- Need to start braking
    elseif dist < bdist then
       if ai.instantJump() then
-         ai.pushsubtask("_hyp_jump", target)
+         ai.pushsubtask(jumptsk, target)
       else
-         ai.pushsubtask("_hyp_jump", target)
+         ai.pushsubtask(jumptsk, target)
          ai.pushsubtask("_subbrake")
       end
    end
@@ -783,6 +794,22 @@ function _hyp_jump ( jump )
    ai.popsubtask() -- Keep the task even if succeeding in case pilot gets pushed away.
 end
 
+-- luacheck: globals _hyp_jump_follow (AI Task functions passed by name)
+function _hyp_jump_follow( jump )
+   local l = ai.pilot():leader()
+   if l and l:exists() then
+      -- Wait until leader is in hyperspace
+      if l:flags("jumpingout") then
+         _hyp_jump( jump )
+      elseif not ai.canHyperspace() then
+         -- Drifted away or whatever, so pop and go back
+         ai.popsubtask()
+      end
+   else
+      _hyp_jump( jump )
+   end
+end
+
 
 --[[
 -- Boards the target
