@@ -30,7 +30,6 @@ function scans.check_visible( target )
    return false
 end
 
-
 --[[
 -- Aborts current task and tries to see what happened to the target.
 --]]
@@ -40,18 +39,21 @@ function scans.investigate( target )
    ai.poptask()
 
    -- No need to investigate: target has jumped out.
-   if target:flags("jumpingout") then
+   if target:flags("jumpingout") or target:flags("landing") then
       return
    end
 
    -- Guess the pilot will be randomly between the current position and the
    -- future position if they go in the same direction with the same velocity
-   local ttl = ai.dist(target) / p:stats().speed_max
+   local ttl = ai.dist(target) / p:speedMax()
    local fpos = target:pos() + vec2.newP( target:vel():mod()*ttl, target:dir() ) * rnd.rnd()
+   mem._scan_last = target
    ai.pushtask("inspect_moveto", fpos )
 end
 
-
+--[[--
+   Initializes a scanning task to target
+--]]
 function scans.push( target )
    -- Send a message if applicable
    local msg = mem.scan_msg or _("Prepare to be scanned.")
@@ -59,9 +61,8 @@ function scans.push( target )
    ai.pushtask( "scan", target )
 end
 
-
---[[
--- Tries to get close to scan the enemy
+--[[--
+   Tries to get close to scan the enemy
 --]]
 function scans.scan( target )
    if not target:exists() then
@@ -117,12 +118,9 @@ function scans.scan( target )
       return
    end
 
-   -- Get stats about the enemy
-   local dist = ai.dist(target)
-
    -- Get closer and scan
-   ai.iface( target )
-   if dist > 1000 then
+   local off = ai.iface( target )
+   if off < math.rad(30) and ai.dist2(target) > 1000*1000 then
       ai.accel()
    end
 end
@@ -147,7 +145,6 @@ local function __needs_scan( target )
    return true
 end
 
-
 --[[
 -- Whether or not we want to scan, ignore players for now
 --]]
@@ -177,7 +174,6 @@ local function __wanttoscan( p, target )
    return true
 end
 
-
 --[[
 -- Tries to get find a good target to scan with some heuristics based on mass
 -- and distance
@@ -188,6 +184,7 @@ function scans.get_target ()
    local pv = {}
    do
       local inserted = {}
+      -- TODO probably try to change this to getInrange() instead to be a bit faster
       for k,v in ipairs(p:getVisible()) do
          -- Only care about leaders
          local l = v:leader()
@@ -235,5 +232,4 @@ function scans.get_target ()
    return pv[1].p
 end
 
-
 return scans
