@@ -13,15 +13,16 @@ local nw, nh
 
 local bgshader = {}
 local bgshader_mt = { __index = bgshader }
-local bgbright
 
 function bgshaders.init( shader, scale, params )
+   params = params or {}
    nw, nh = naev.gfx.dim()
 
    local shd = {
       bgshader = shader,
       bgscale  = scale or 1,
-      params   = params or {},
+      bgbright = 1,
+      params   = params,
    }
    setmetatable( shd, bgshader_mt )
 
@@ -34,12 +35,15 @@ function bgshaders.init( shader, scale, params )
       shd.prevcanvas = lg.newCanvas( shd.cw, shd.ch )
    end
 
-   bgbright =  naev.conf().bg_brightness
+   if not shd.params.nobright then
+      shd.bgbright = naev.conf().bg_brightness
+   end
 
    return shd
 end
 
 function bgshader:render( dt, col )
+   local bgbright = self.bgbright
    dt = dt or 0
    col = col or {1, 1, 1, 1}
    col[1] = col[1] * bgbright
@@ -65,7 +69,7 @@ function bgshader:render( dt, col )
       lg.setCanvas( self.bgcanvas )
       lg.clear( 0, 0, 0, 0 )
       lg.setShader( self.bgshader )
-      lg.setColor( col )
+      lg.setColour( col )
       lg.setBlendMode( "alpha", "premultiplied" )
       love_shaders.img:draw( 0, 0, 0, self.cw, self.ch )
       lg.setBlendMode( "alpha" )
@@ -73,7 +77,7 @@ function bgshader:render( dt, col )
       lg.setCanvas( oldcanvas )
 
       -- Render to screen
-      lg.setColor( 1, 1, 1, 1 )
+      lg.setColour( 1, 1, 1, 1 )
       self.bgcanvas:draw( 0, 0, 0, self.bgscale, self.bgscale )
 
       -- Swap buffers
@@ -84,7 +88,7 @@ function bgshader:render( dt, col )
    end
 
    -- Native resolution
-   lg.setColor( col )
+   lg.setColour( col )
    local oldshader = lg.getShader()
    lg.setShader( self.bgshader )
    love_shaders.img:draw( 0, 0, 0, nw, nh )
