@@ -37,7 +37,7 @@ local hypergate_list = {
 
 function create ()
    -- Set up some variables
-   local has_license = diff.isApplied("heavy_combat_vessel_license") or (player.numOutfit("Heavy Combat Vessel License") > 0)
+   local has_license = diff.isApplied("heavy_combat_vessel_license") or (player.outfitNum("Heavy Combat Vessel License") > 0)
    local traded_total = var.peek("hypconst_traded_total") or 0
 
    -- Compute some sort of progress value
@@ -59,7 +59,7 @@ function create ()
       end
 
       -- Make sure system isn't claimed, but we don't claim it
-      if not evt.claim( system.cur(), true ) then evt.finish(false) end
+      if not naev.claimTest( system.cur() ) then evt.finish(false) end
 
       -- Sort the hypergates by player standing
       table.sort( hypergate_list, function ( a, b )
@@ -68,6 +68,15 @@ function create ()
          return sa > sb
       end )
 
+      -- Let us claim the systems
+      local claimsys = {}
+      for k,h in ipairs(hypergate_list) do
+         table.insert( claimsys, h:system() )
+      end
+      if not evt.claim( claimsys ) then
+         evt.finish(false)
+      end
+
       hook.safe( "cutscene_start" )
       return -- Don't finish
 
@@ -134,11 +143,11 @@ end
 
 function foreground ()
    if fg.alpha > 0 then
-      lg.setColor( 0, 0, 0, fg.alpha )
+      lg.setColour( 0, 0, 0, fg.alpha )
       lg.rectangle( "fill", 0, 0, nw, nh )
 
       if fg.text then
-         lg.setColor( 1, 1, 1, fg.alpha )
+         lg.setColour( 1, 1, 1, fg.alpha )
          lg.printf( fg.text, fg.font, fg.x, fg.y, 0.6*nw, "center" )
       end
    end
@@ -208,7 +217,7 @@ local function getFactionStuff( fct )
          end
       end
       tester_broadcast = _("For science!")
-      boss_broadcast = _("Comencing procedure!")
+      boss_broadcast = _("Commencing procedure!")
    elseif fct == "Sirius" then
       bossship = "Sirius Divinity"
       testership = "Sirius Preacher"
@@ -646,7 +655,7 @@ function land ()
    vn.scene()
    local sai = vn.newCharacter( tut.vn_shipai() )
    vn.transition( tut.shipai.transition )
-   vn.na(fmt.f(_("As soon as your ship lands, your ship AI {shipai} materializes infront of you."),{shipai=tut.ainame()}))
+   vn.na(fmt.f(_("As soon as your ship lands, your ship AI {shipai} materializes in front of you."),{shipai=tut.ainame()}))
    sai(fmt.f(_([["Did you hear the news, {playername}? It seems like the hypergate network has finally gone online!"]]), {playername=player.name()}))
    vn.menu{
       {_([["A great achievement!"]]), "cont01"},
@@ -654,7 +663,7 @@ function land ()
       {_("…"), "cont01"},
    }
    vn.label("cont01")
-   sai(_([["Yes, my predition routines did not anticipate this. Total annihilation was the most likely outcome. I have to revise my priors."]]))
+   sai(_([["Yes, my prediction routines did not anticipate this. Total annihilation was the most likely outcome. I have to revise my priors."]]))
    sai(_([["Although the details are not entirely clear, it seems like they are not based on hyperjump technology, which is why they allow very long distance travel."]]))
    sai(_([["We should try to use them when we get a chance, who knows where we could go?"]]))
    sai(_([["I almost forgot to mention, while you were piloting, I managed to unlock an important bottleneck in the ship fleet routines."]]))
