@@ -66,7 +66,7 @@ function ambusher()
       baddie:outfitAdd("Milspec Thalos 2202 Core System")
       baddie:outfitAdd("Tricon Zephyr Engine")
       baddie:outfitAdd("Reactor Class I")
-      baddie:outfitAdd("Razor MK1",3)
+      baddie:outfitAdd("Razor Artillery S1",3)
       baddie:outfitAdd("Improved Stabilizer")
    elseif vel >= 210 then
       baddie:outfitAdd("S&K Light Combat Plating")
@@ -74,7 +74,7 @@ function ambusher()
       baddie:outfitAdd("Tricon Zephyr II Engine")
       baddie:outfitAdd("Reactor Class I",3)
       baddie:outfitAdd("TeraCom Headhunter Launcher")
-      baddie:outfitAdd("Razor MK1",3)
+      baddie:outfitAdd("Razor Artillery S1",3)
       --baddie:outfitAdd("Power Regulation Override",2)
    elseif vel >= 140 then
       baddie:outfitAdd("S&K Light Combat Plating")
@@ -82,7 +82,7 @@ function ambusher()
       baddie:outfitAdd("Tricon Zephyr II Engine")
       baddie:outfitAdd("Small Shield Booster",2)
       baddie:outfitAdd("TeraCom Headhunter Launcher",2)
-      baddie:outfitAdd("Razor MK1",2)
+      baddie:outfitAdd("Razor Artillery S1",2)
       baddie:outfitAdd("Improved Stabilizer")
    else
       --baddie:outfitAdd("S&K Light Stealth Plating")
