@@ -1,8 +1,9 @@
 --[[
 <?xml version='1.0' encoding='utf8'?>
 <event name="Pirate Shipcheck">
- <location>enter</location>
+ <location>load</location>
  <chance>100</chance>
+ <unique />
 </event>
 --]]
 --[[
@@ -11,6 +12,8 @@
 --]]
 local pir = require 'common.pirate'
 function create()
+   hook.enter( "enter" )
+end
+function enter ()
    pir.updateStandings()
-   evt.finish()
 end
