@@ -125,21 +125,22 @@ local function clicked ()
    vn.label("tut_weaponsets")
    sai(_([["A large part of combat is decided ahead of time by the ship classes and their load out. However, good piloting can turn the tables easily. It is important to assign weapon sets to be easy to use. You can set weapon sets from the '#oWeapons#0' tab of the information window. You have 10 different weapon sets that can be configured separately for each ship."]]))
    sai(_([["There are three different types of weapon sets:
-- #oWeapons - Switched#0: activating the hotkey will set your primary and secondary weapons
-- #oWeapons - Instant#0: activating the hotkey will fire the weapons
-- #oAbilities - Toggled#0: activating the hotkey will toggle the state of the outfits]]))
-   sai(_([["By default, the weapon sets will be automatically managed by me, with forward bolts in set 1 (switched), turret weapons in set 2 (switched), and both turret and forward weapons in set 3 (switched). Seeker weapons are in set 4 (instant), and fighter bays in set 5 (instant). However, you can override this and set them however you prefer. Just remember to update them whenever you change your outfits."]]))
+- #oSwitch#0: activating the hotkey will set your primary and secondary weapons
+- #oToggle#0: activating the hotkey will toggle the outfits between on/off states
+- #oHold#0: holding the hotkey will turn the outfits on]]))
+   sai(_([["By default, the weapon sets will be automatically managed by me, with forward bolts in set 1 (switch), turret weapons in set 2 (switch), and both turret and forward weapons in set 3 (switch). Seeker weapons are in set 4 (hold), and fighter bays in set 5 (hold). However, you can override this and set them however you prefer. Just remember to update them whenever you change your outfits."]]))
    vn.jump("tutorials")
 
    vn.label("tut_ewarfare")
    sai(_([["Ship sensors are based on detecting gravitational anomalies, and thus the mass of a ship plays a critical role in being detected. Smaller ships like yachts or interceptors are inherently much harder to detect than carriers or battleship."]]))
    sai(p_("Ship AI", [["Each ship has three important electronic warfare statistics:
 - #oDetection#0 determines the distance at which a ship appears on the radar.
-- #oEvasion#0 determines the distance at which a ship is fully detected, that is, ship type and faction are visible. It also plays a role in how missiles and weapons track the ship.
+- #oSignature#0 determines the distance at which a ship is fully detected, that is, ship type and faction are visible. It also plays a role in how missiles and weapons track the ship.
 - #oStealth#0 determines the distance at which the ship is undetected when in stealth mode"]]))
-   sai(_([["#oDetection#0 plays a crucial in how much attention you draw in a system, and detection bonuses can be very useful for avoiding lurking dangers. Furthermore, concealment bonuses will lower your detection, evasion, and stealth ranges, making outfits that give concealment bonuses very useful if you get your hands on them."]]))
-   sai(_([["#oEvasion#0 is very important when it comes to combat as it determines how well weapons can track your ship. If your evasion is below your enemies weapon's #ominimal tracking#0, their weapons will not be able to accurately target your ship at all. However, if your evasion is above the #ooptimal tracking#0, you will be tracked perfectly. Same goes for your targets. This also has an effect on launcher lock-on time, with lower evasion increasing the time it takes for rockets to lock on to you."]]))
+   sai(_([["#oDetection#0 plays a crucial in how much attention you draw in a system, and detection bonuses can be very useful for avoiding lurking dangers. Furthermore, concealment bonuses will lower your detection, signature, and stealth ranges, making outfits that give concealment bonuses very useful if you get your hands on them."]]))
+   sai(_([["#oSignature#0 is very important when it comes to combat as it determines how well weapons can track your ship. If your signature is below your enemies weapon's #ominimal tracking#0, their weapons will not be able to accurately target your ship at all. However, if your signature is above the #ooptimal tracking#0, you will be tracked perfectly. Same goes for your targets. This also has an effect on launcher lock-on time, with lower signature increasing the time it takes for rockets to lock on to you."]]))
    sai(fmt.f(_([["#oStealth#0 is a whole different beast and is only useful when entering stealth mode with {stealthkey}. If you want to learn more about stealth, please ask me about it."]]),{stealthkey=tut.getKey("stealth")}))
+   sai(_([["Finally, ships that are scanning your ship will be marked on your radar and overlay map. Depending on what you are carrying, there are times that you will not want to be scanned, and this icon can help you get away."]]))
    vn.jump("tutorials")
 
    vn.label("tut_stealth")
@@ -150,7 +151,7 @@ local function clicked ()
    vn.jump("tutorials")
 
    vn.label("tut_mining")
-   sai(_([["Asteroid mining can be a lucrative business. Asteroid field scan be found throughout the galaxy in many different shapes and sizes. They can be a good source of many precious materials that fetch a good price on the commodity exchange. However, not all asteroid fields are made equal. In general, the more easily accessible asteroid fields are generally over-mined, leading to low yields. On the other hand, hard to access asteroid fields in dangerous areas have not yet succumbed to the hordes of ravenous mining fleets. If you find a good mining spot, I recommend you add a note on the #bSystem Map#0 so you don't forget."]]))
+   sai(_([["Asteroid mining can be a lucrative business. Asteroid field scan be found throughout the galaxy in many shapes and sizes. They can be a good source of many precious materials that fetch a good price on the commodity exchange. However, not all asteroid fields are made equal. In general, the more easily accessible asteroid fields are generally over-mined, leading to low yields. On the other hand, hard to access asteroid fields in dangerous areas have not yet succumbed to the hordes of ravenous mining fleets. If you find a good mining spot, I recommend you add a note on the #bSystem Map#0 so you don't forget."]]))
    sai(_([["Standard ship sensors are not designed for prospecting asteroid fields, so if you want to be able to get a rough estimate of what materials are in each asteroid, you will need to get an asteroid scanner. They can be either sold as standalone outfits, or integrated into mining tools such as drills. With an asteroid scanner equipped, all you have to do is get close to asteroids and their material composition will be displayed. You can also equip multiple asteroid scanners at the same time to increase the scanning range."]]))
    sai(fmt.f(_([["Once you have found a good potential mining spot, mining is as straight forward as shooting asteroid with damaging weapons. However, with most weapons, this will only yield common materials and not be a very efficient way of mining. By using mining-specific weapons such as {tool1}, you can also obtain more expensive materials. Furthermore, integrated tools such as {tool2} can be used as a solution for both scanning and extraction. One important point is that asteroid mining is fairly noisy and can attract unwanted attention. One of my previous owners found that out the hard way."]]),
       {tool1=outfit.get("Mining Lance MK1"), tool2=outfit.get("S&K Plasma Drill")}))
@@ -158,7 +159,8 @@ local function clicked ()
 
    vn.label("tut_bioship")
    -- TODO more text
-   sai(fmt.f(_([["You can see the status of your current bioship from the #bInfo menu#0, which you can access with {infokey}. As your bioship gains experience, and advances to new stages, you'll be able to obtain new skills that open up new possibilities. Make sure to choose your skills carefully as it is not easy to change them once they have been chosen."]]),{infokey=tut.getKey("info")}))
+   sai(fmt.f(_([["You can see the status of your current bioship from the #bInfo menu#0, which you can access with {infokey}. As your bioship gains experience, and advances to new stages, you'll be able to obtain new skills that open up new possibilities. Make sure to choose your skills carefully as there is an experience loss to change them once they have been chosen."]]),{infokey=tut.getKey("info")}))
+   sai(_([["You can only change your skills when landed, and if you have free skill points, the bioship button in the #bInfo menu#0 will be marked with #r!!#0 to make it clear. Skill is gained naturally as you do missions, but only your active bioship will be gaining experience."]]))
    vn.jump("tutorials")
 
    vn.label("tut_illegal")
@@ -173,8 +175,8 @@ local function clicked ()
    sai(_([["With my overriding of the disable routine on the fleet procedure, you can now deploy additional ships you own. You have a maximum amount of fleet capacity, indicated in the equipment tab when landed, and each ship consumes a fixed amount of fleet capacity."]]))
    sai(fmt.f(_([["For example, you have a total fleet capacity of {fleetcap} points, and your current ship takes {shipcap} points. Note that if you are flying a single ship with no additional deployed ships, you can go over the fleet capacity. However, if you deploy additional ships, you have to stay below the total fleet capacity."]]),
       {fleetcap=player.fleetCapacity(), shipcap=player.pilot():ship():points()}))
-   sai(_([["It is important to note that fleet capacity depends exclusively on the ship, and is not affected by normal outfits. Make sure to equip your ships as best as possible!"]]))
-   sai(_([["Your additional ships will behave as escorts and you can give them commands to perform actions just like deployed fighters. Furthermore, they are all insured so even if you lose any ships, they will respawn when you land."]]))
+   sai(_([["It is important to note that fleet capacity depends exclusively on the ship, and is not affected by normal outfits. Make sure to equip your ships as good as possible!"]]))
+   sai(_([["Your additional ships will behave as escorts, and you can give them commands to perform actions just like deployed fighters. Furthermore, they are all insured so even if you lose any ships, they will respawn when you land."]]))
    sai(_([["Finally, you can toggle ships' deployment by #bright-clicking#0 on their icon. Try it out!"]]))
    vn.jump("tutorials")
 
@@ -190,7 +192,7 @@ function advice ()
    local pp = player.pilot()
    local ppstats = pp:stats()
 
-   local msg_fuel = _([["When out of fuel, if there is an inhabitable planet you can land to refuel for free. However, if you want to save time or have no other option, it is possible to hail passing ships to get refueled, or even take fuel by force by boarding ships. Bribing hostile ships can also encourage them to give you fuel afterwards."]])
+   local msg_fuel = _([["When out of fuel, if there is an inhabitable planet you can land to refuel for free. However, if you want to save time or have no other option, it is possible to hail passing ships to get refuelled, or even take fuel by force by boarding ships. Bribing hostile ships can also encourage them to give you fuel afterwards."]])
    table.insert( adv_rnd, msg_fuel )
    if ppstats.fuel < ppstats.fuel_consumption then
       table.insert( adv, msg_fuel )
@@ -204,7 +206,7 @@ function advice ()
    end
 
    local _hmean, hpeak = pp:weapsetHeat(true)
-   local msg_heat = fmt.f(_([["When your ship or weapons get very hot, it is usually a good idea to perform an active cooldown when it is safe to do so. You can actively cooldown with {cooldownkey} or double-tapping {reversekey}. The amount it takes to cooldown depends on the size of the ship, but when done, not only will your ship be cool, it will also have replenished all ammunition and fighters."]]),{cooldownkey=tut.getKey("cooldown"), reversekey=tut.getKey("reverse")})
+   local msg_heat = fmt.f(_([["When your ship or weapons get very hot, it is usually a good idea to perform an active cooldown when it is safe to do so. You can actively cool down with {cooldownkey} or double-tapping {reversekey}. The amount it takes to cooldown depends on the size of the ship, but when done, not only will your ship be cool, it will also have replenished all ammunition and fighters."]]),{cooldownkey=tut.getKey("cooldown"), reversekey=tut.getKey("reverse")})
    table.insert( adv_rnd, msg_heat )
    if pp:temp() > 300 or hpeak > 0.2 then
       table.insert( adv, msg_heat )
@@ -218,7 +220,7 @@ function advice ()
    end
 
    local armour = pp:health()
-   local msg_armour = _([["In general, ships are unable to regenerate armour damage in space. If you take heavy armour damage, it is best to try to find a safe place to land to get fully repaired. However, there exists many different outfits that allow you to repair your ship, and some ships have built-in  armour regeneration allowing you to survive longer in space."]])
+   local msg_armour = _([["In general, ships are unable to regenerate armour damage in space. If you take heavy armour damage, it is best to try to find a safe place to land to get fully repaired. However, there exists many outfits that allow you to repair your ship, and some ships have built-in armour regeneration allowing you to survive longer in space."]])
    table.insert( adv_rnd, msg_armour )
    if armour < 80 and ppstats.armour_regen <= 0 then
       table.insert( adv, msg_armour )
