@@ -1,7 +1,6 @@
 -- Collective faction standing script
 local sbase = require "factions.standing.lib.base"
-
-standing = sbase.newStanding{
+sbase.init{
    fct            = faction.get("Collective"),
    cap_kill       = 30,
    delta_distress = {0, 0},     -- Maximum change constraints
