@@ -1,6 +1,5 @@
 -- Dreamer Clan faction standing script
 local spir = require "factions.standing.lib.pirate"
-
-standing = spir.newPirateStanding{
+spir.init{
    fct = faction.get("Dreamer Clan"),
 }
