@@ -1,8 +1,6 @@
 -- Static standing script: used for temporary/dynamic factions.
 local sbase = require "factions.standing.lib.base"
-
-standing = sbase.newStanding{}
-
-function standing.hit( _self, current, _amount, _source, _secondary )
+sbase.init()
+function hit( current, _amount, _source, _secondary )
    return current -- Doesn't change through hits
 end
