@@ -44,16 +44,16 @@ escort_hailed = fw.escort_hailed -- common hooks
 local destpla, destsys = spob.getS("Mannannan")
 local lore_text = {}
 
-lore_text[1] = _([["Good question, citizen! It is likely the intelligence services of the other nations know that General Klank and I are involved in the invasion project. Though, they probably don't know how imminent it is. It's likely they hired henchmen to hound or outright stop us. We have identified some of the henchmen actually. They are the kind of independent mercenaries we find in any kind of shady operations... A bit like you in fact."]])
+lore_text[1] = _([["Good question, citizen! It is likely the intelligence services of the other nations know that General Klank and I are involved in the invasion project. Though, they probably don't know how imminent it is. It's likely they hired henchmen to hound or outright stop us. We have identified some of the henchmen, actually. They are the kind of independent mercenaries we find in any kind of shady operations... A bit like you in fact."]])
 
 lore_text[2] = _([["Aha! You're worrying about the soldiers of the warlord we killed last time? Don't worry too much about them, most of them did not stay unemployed for long. When a warlord dies, his surviving followers are sent to the Dvaered Military Reserve, and they apply for positions in other warlords' armies, or in the DHC. The only one I'm worried about is Colonel Hamelsen: it will be very difficult for her to find a position with a warlord since they prefer to have people they know at higher ranks, and the DHC only rarely recruits new colonels.
    "That's a pity actually because she is probably the most talented officer of her generation. Do you know that she was the first one since the Independence War who managed to become an ace before the end of her training?"]])
 
-lore_text[3] = _([[You ask Major Tam to continue his story about when he used to be a fighter pilot at the DHC base on Rhaana. A small smile appears on his face and he turns his eyes to the cieling.
-   "Do you want me to tell you how I became an ace? Oh yes, you do. So. To become a Dvaered ace, one has to score four confirmed fighter victories. An confirmed victory is recorded when you, alone, destroy any kind of enemy warship. As we tend to work in squads, we pretty often destroy ships without scoring any confirmed victories. My first victory was a Pirate Hyena. The pilot was probably drunk or something. They headed right towards my Vendetta, broadcasting stupid taunts. My sergeant was nice and left the Hyena all to me. My second victory was against a freak... I mean a local warlord's pilot who claimed she could kill any DHC pilot in fair fight. Apparently, it was not true.
-   "But the two others... Actually those are a much longer story. I'll tell you another time maybe."]])
+lore_text[3] = _([[You ask Major Tam to continue his story about when he used to be a fighter pilot at the DHC base on Rhaana. A small smile appears on his face, and he turns his eyes to the ceiling.
+   "Do you want me to tell you how I became an ace? Oh yes, you do. So. To become a Dvaered ace, one has to score four confirmed fighter victories. A confirmed victory is recorded when you, alone, destroy any kind of enemy warship. As we tend to work in squads, we pretty often destroy ships without scoring any confirmed victories. My first victory was a Pirate Hyena. The pilot was probably drunk or something. They headed right towards my Vendetta, broadcasting stupid taunts. My sergeant was nice and left the Hyena all to me. My second victory was against a freak... I mean a local warlord's pilot who claimed she could kill any DHC pilot in fair fight. Apparently, it was not true.
+   "But the two others... Actually those are a much longer story. I'll tell you another time, maybe."]])
 
-lore_text[4] = _([["Oh, the captain is doing well. He spent a few periods at the hospital, but it was not so serious. The rest of his squad, I'm not too sure. I don't know them very well actually. They are more like statistics to me. I know it's bad, but hey, I have so many things to think about right now.
+lore_text[4] = _([["Oh, the captain is doing well. He spent a few periods at the hospital, but it was not so serious. The rest of his squad, I'm not too sure. I don't know them very well, actually. They are more like statistics to me. I know it's bad, but hey, I have so many things to think about right now.
    "Oh, and we went to the funeral of private Amadeus Tronk, officially killed in training, of course. It was nice. Leblanc's squadron made an aerial display with a mace rocket concerto for the occasion, and we organized a fight to death between a convicted criminal and a gladiator in General Klank's private arena. Not only to honour the memory of the dead warrior, but also to have some fun."]])
 
 local flee_text = _("You were supposed to wait for Strafer to scan the system, and then if needed, kill the hostiles.")
@@ -81,7 +81,7 @@ end
 
 function accept()
    if not tk.yesno( _("Ready for some diplomacy?"), fmt.f(_([[Major Tam seems to be in a very good mood: "Hello, citizen {player}! Have you got plans for tonight?" You fear he might invite you to a brawl-party, or some other kind of event Dvaered usually organize when they want to have good time, but he continues: "Because I've got a very important mission for you.
-   "Let me explain: I am currently in the middle of a secret diplomatic campaign with the Imperials, House Goddard, and the Sirii. But a group of assassins is constantly harassing me as I travel. This is very annoying and we have already lost two pilots of Leblanc's squadron in these ambushes, including the second in command. The attackers use a mix of fighters supported by medium ships. They even have a Kestrel!
+   "Let me explain: I am currently in the middle of a secret diplomatic campaign with the Imperials, House Goddard, and the Sirii. But a group of assassins is constantly harassing me as I travel. This is very annoying, and we have already lost two pilots of Leblanc's squadron in these ambushes, including the second in command. The attackers use a mix of fighters supported by medium ships. They even have a Kestrel!
    "So we have decided to deal with them before we proceed with the diplomatic meetings. Are you in?"]]), {player=player.name()}) ) then
       tk.msg(_("Another time maybe"), _([[Major Tam really seems disappointed. "As you wish, citizen..."]]))
       return
@@ -152,10 +152,7 @@ function enter()
          escort[1]:moveto( ambJp:pos() )  -- Let's say Strafer knows where they are supposed to come from...
 
          if system.cur() == mem.ambushsys then
-            for k,f in ipairs(pir.factions) do
-               pilot.toggleSpawn(f)
-               pilot.clearSelect(f)
-            end
+            pir.clearPirates()
             spawnBaddies( mem.ambStart )
 
             -- Find the waiting point: on the line mem.tamPoint -> ambJp, at 3000 of mem.tamPoint
@@ -418,7 +415,7 @@ function escort_died3( )
    mem.alive[3] = false
 end
 function tamDied()
-   tk.msg(_("This is not good"), _([[The blinking cross marked "Major Tam" on your radar screen suddenly turns off. At first you think your screen is buggy and hit it with your open hand, but soon, you realize that the radar works perfectly well. This means that the major's ship was annihilated by the ambushers, and therefore your mission is a miserable failure.]]))
+   tk.msg(_("This is not good"), _([[The blinking cross marked "Major Tam" on your radar screen suddenly turns off. At first, you think your screen is buggy and hit it with your open hand, but soon, you realize that the radar works perfectly well. This means that the major's ship was annihilated by the ambushers, and therefore your mission is a miserable failure.]]))
    misn.finish(false)
 end
 
@@ -598,7 +595,7 @@ end
 function payNfinish()
    player.pay(mem.effective_credits)
    shiplog.create( "frontier_war", _("Frontier War"), _("Dvaered") )
-   shiplog.append( "frontier_war", _("A group of assasins, who were after Major Tam, have been trapped and killed. For now, we don't know who paid them, but they were led by Colonel Hamelsen, who managed to escape.") )
+   shiplog.append( "frontier_war", _("A group of assassins, who were after Major Tam, have been trapped and killed. For now, we don't know who paid them, but they were led by Colonel Hamelsen, who managed to escape.") )
    misn.finish(true)
 end
 
