@@ -7,7 +7,20 @@
  <location>Bar</location>
  <faction>Dvaered</faction>
  <done>Dvaered Census 0</done>
- <cond>faction.playerStanding("Dvaered") &gt;= 20 and player.numOutfit("Mercenary License") &gt; 0 and (not diff.isApplied("flf_dead"))</cond>
+ <cond>
+   if faction.playerStanding("Dvaered") &lt;= 20 then
+      return false
+   end
+   if diff.isApplied("flf_dead") then
+      return false
+   end
+   local misn_test = require "misn_test"
+   if not misn_test.mercenary(true) then
+      return false
+   end
+   --return misn_test.reweight_active() -- don't reweight for licenses
+   return true
+ </cond>
  <notes>
   <tier>3</tier>
   <campaign>Dvaered Recruitment</campaign>
@@ -55,7 +68,7 @@ local agentPort = "neutral/female1.webp"
 function create()
    mem.flfsys  = system.get("Theras")
    mem.flfoys  = system.get("Haleb") -- Origin of the target
-   mem.duchpnt, mem.duchsys  = spob.getS("Myuirr Station")
+   mem.duchpnt, mem.duchsys  = spob.getS("Fort Myuirr")
 
    if not misn.claim({mem.flfsys,mem.duchsys}) then misn.finish(false) end -- Claim
 
@@ -96,7 +109,7 @@ Red-painted ships, mace rockets and big nose drawings... This mission might be t
 
    vn.label("accept")
    sol(_([[Good choice, citizen!]]))
-   sol(fmt.f(_([[So, as said, go to {pnt} in {sys}. There, you will meet our contact agent named Bony Boudica who will take the cargo in charge. I'll give you a datapad containing informations to identify her.
+   sol(fmt.f(_([[So, as said, go to {pnt} in {sys}. There, you will meet our contact agent named Bony Boudica who will take the cargo in charge. I'll give you a datapad containing information to identify her.
 Oh, I almost forgot! There is one thing you are authorized to know: this cargo is transferred to the Empire as a part of the Dvaered-Empire collaboration program.]]), {pnt=mem.spob1:name(), sys=sys}))
    vn.func( function () doaccept = true end )
    vn.done()
@@ -108,7 +121,7 @@ Oh, I almost forgot! There is one thing you are authorized to know: this cargo i
    -- Mission details
    mem.credits = 50e3
    misn.setTitle(_("Dvaered Delivery"))
-   misn.setReward( fmt.credits( mem.credits ) )
+   misn.setReward( mem.credits )
    misn.setDesc( fmt.f(_("You have to transfer a parcel to the Empire at {pnt} ({sys})"), {pnt=mem.spob1,sys=sys}))
    mem.misn_marker = misn.markerAdd( mem.spob1 )
    mem.misn_state = 0
@@ -206,11 +219,11 @@ A seemingly-unarmed man steps forward. He must be the imperial agent in charge o
       agent1(_([[Not so bad on my side. Glad to see you too, Ak-Ak. I would just have preferred we meet in different circumstances. Any news of your pilot?]]))
       agent2(_([[Neh. Not a single clue. I'd say the safest bet is that the FLF is implied.]]))
       agent1(_([[How would they have known?]]))
-      agent2(_([[Dunno. Anyways, you remember when I told ya we didn't know where "Shaky Swan" was?]]))
+      agent2(_([[Dunno. Anyway, you remember when I told ya we didn't know where "Shaky Swan" was?]]))
       agent1(_([[Yep.]]))
       agent2(_([[It was not true.]]))
       agent1(_([[Oooh. I'm sooo surprised! I totally was not expecting you to lie at all about that!]]))
-      agent2(fmt.f(_([[Come on... Anyways, I think it's time to get that swan. If the FLF is implied in the disappearance, so is the swan. The good thing is that we know that he is supposed to have business in {sys} soon.]]),{sys=mem.flfsys}))
+      agent2(fmt.f(_([[Come on... Anyway, I think it's time to get that swan. If the FLF is implied in the disappearance, so is the swan. The good thing is that we know that he is supposed to have business in {sys} soon.]]),{sys=mem.flfsys}))
       agent1(_([[Nice to hear that from you. But why do you tell it to me? Just send the flying circus after him.]])) -- Flying Circus is the surname of the squadron of the red baron during WWI, And in game, I plan it to be the surname of an imperial black ops squadron.
       agent2(_([[Yeah, I've made a backup request to the Imperial Lair's Secretary, but the Second Archbishop of Mayhem has opposed a veto, so I only have access to the squadrons that are outside of his jurisdiction. And I finally got squadron 138...]]))
       agent1(_([[Man, I don't care of your Bishop of Myass, nor of the ID of your squadron. Just get them to intercept the swan.]]))
@@ -230,9 +243,10 @@ A seemingly-unarmed man steps forward. He must be the imperial agent in charge o
       vn.clear()
       vn.scene()
       local agent = vn.newCharacter( _("Intermediate"), { image=portrait.getFullPath(agentPort) } )
+      vn.transition()
       vn.na(_([[Bony Boudica was waiting for you at the dock.]]))
       agent(fmt.f(_([[Hi, {name}. Did you have fun out there with the Imperial pilots?
-Meanwhile, our boy Ak-Ak did make his investigation. He got his cyborgs to break a few knees and now we know what happened to the lost pilot.]]),{name=player.name()}))
+Meanwhile, our boy Ak-Ak did make his investigation. He got his cyborgs to break a few knees, and now we know what happened to the lost pilot.]]),{name=player.name()}))
       agent(_([[Actually, Shaky Swan has nothing to do with that. Nor the FLF. The Empire pilot just accepted a random bounty hunt mission on their way to the rendezvous planet. And they miserably failed.]]))
       agent(_([[And now, the Imperials want to avenge their pilot. They found track to the pirate pilot, who is called 'The Death Dealer'. He is a clanless pirate, wanted by the Imperial police, as well as a few other faction's authorities. But he never broke the law in Dvaered space, where he is a peaceful trader under his real name: Chilperic Duchmol.]]))
       agent(fmt.f(_([[So, Duchmol is supposed to take off from {pnt} in {sys} with his Koala soon.
@@ -260,6 +274,7 @@ And again, be ensured that your initial reward will be dramatically increased fr
       vn.clear()
       vn.scene()
       local agent = vn.newCharacter( _("Intermediate"), { image=portrait.getFullPath(agentPort) } )
+      vn.transition()
       vn.na(_([[After landing, you once again meet Bony Boudica. And hopefully now, she has a nice reward for you.]]))
       agent(fmt.f(_([[Hi, {name}. How do you do?]]),{name=player.name()}))
       vn.menu{
@@ -278,7 +293,7 @@ And again, be ensured that your initial reward will be dramatically increased fr
 
       vn.label("well")
       agent(fmt.f(_([[Now that Chilperic Duchmol aka The Death Dealer is no more, your mission is over and it is my utmost privilege to reward you the sum of {credits} in name of the Dvaered High Command.]]),{credits=fmt.credits(reward)}))
-      agent(_([[The fact that this mission did not go as planned is actually a rather good thing for you, you know: now you have proven to the Dvaered High Command that you are a reliable pilot. I don't know if you intend to continue working for them, but I have informations that suggest that they might offer you more work in the future.]]))
+      agent(_([[The fact that this mission did not go as planned is actually a rather good thing for you, you know: now you have proven to the Dvaered High Command that you are a reliable pilot. I don't know if you intend to continue working for them, but I have information that suggest that they might offer you more work in the future.]]))
 
       vn.done()
       vn.run()
@@ -324,6 +339,7 @@ function discussWithAg()
    vn.clear()
    vn.scene()
    local agent = vn.newCharacter( _("Bony Boudica"), { image=portrait.getFullPath(agentPort) } )
+   vn.transition()
 
    agent(fmt.f(_([[I don't know how much you did understand of our conversation on the spaceport, but we need you now to disable the ship of a pilot surnamed 'Shaky Swan'. He is supposed to be hanging around {sys} in the near future.]]),{sys=mem.flfsys}))
 
@@ -372,8 +388,8 @@ Your task will be to approach, engage and disable his ship. Only afterwards, squ
    agent(_([[Shaky Swan is a shifty individual. Really. I don't know much about them, except for some of their deeds. Some say they used to be an Imperial agent as well. But nowadays, they are more into stuff like assassinations, weapons dealing or even terrorism...]]))
    vn.na(_([[Boudica stops talking and seems to think.]]))
    agent(_([[... Actually, that are the kind of things Imperial agents do.
-But Shaky Swan is also in touch with the FLF and provides them with all kinds of informations and weapons. The Dvaered counter-insurrection task-force, led by Colonel Urnus, has wanted to capture this swan for quite long now.
-We have always suspected that the Imperials are protecting the swan. Anyways, now that a pilot employed by the Empire is missing, they are disposed to capture that individual. The only thing I hope is that they don't set the swan free once they have recovered their pilot.]]))
+But Shaky Swan is also in touch with the FLF and provides them with all kinds of information and weapons. The Dvaered counter-insurrection task-force, led by Colonel Urnus, has wanted to capture this swan for quite long now.
+We have always suspected that the Imperials are protecting the swan. Anyway, now that a pilot employed by the Empire is missing, they are disposed to capture that individual. The only thing I hope is that they don't set the swan free once they have recovered their pilot.]]))
    vn.jump("lore_menu")
 
    vn.label("circus")
@@ -386,7 +402,7 @@ We have always suspected that the Imperials are protecting the swan. Anyways, no
 
    vn.label("protest")
    vn.na(_([["Boudica sighs and turns her face to the roof."]]))
-   agent(fmt.f(_([[Listen, {name}, would you by any chance like the Empire and House Dvaered to trigger an Universal War?]]),{name=player.name()}))
+   agent(fmt.f(_([[Listen, {name}, would you by any chance like the Empire and House Dvaered to trigger a Universal War?]]),{name=player.name()}))
    vn.menu{
       {_("Yes"), "war"},
       {_("No"), "peace"},
@@ -395,7 +411,7 @@ We have always suspected that the Imperials are protecting the swan. Anyways, no
 
    vn.label("war")
    agent(_([[You obviously have no idea what you are talking about.
-Shall you see the death squadrons taking off from Halir, loaded with all the kinds of deadly viruses only human madness can breed. Shall you see the fleet of the united Warlords silently flying towards humanity's doom before an helpless sky of horrified stars. Shall you see them hide the sun of Doranthex as would the black wings of death.
+Shall you see the death squadrons taking off from Halir, loaded with all the kinds of deadly viruses only human madness can breed. Shall you see the fleet of the united Warlords silently flying towards humanity's doom before a helpless sky of horrified stars. Shall you see them hide the sun of Doranthex as would the black wings of death.
 Shall you hear the frenetic lament of sirens while the sky of Antica gets torn apart by the trails of hypersonic bombs. Shall you hear the roaring of space stations, wounded to death by torpedoes, disseminating into the void the helpless bodies of their inhabitants.]]))
    agent(_([[Maybe you think that as a pilot, you won't endure starvation, contrary to the billions of poor souls who will struggle to survive the nuclear winter on their sterilized planets. Maybe you think you won't have to endure the gaze of the slowly dying victims of incendiary bombs, bio-weapons, climatic and seismic bombs...]]))
    agent(_([[But this won't be the worst! Because I've got my informations. And the Empire has weapons even more powerful. Even more abominable. Even more unmentionable and unimaginable. Some say the Incident was provoked by a such weapon. Imagine if they decide to make a new incident happen!
@@ -454,7 +470,7 @@ Your mission is a pitiful failure.]]))
    misn.finish(false)
 end
 function swanBoarded( )
-   vntk.msg("", _([[Once the boarding maneuver is over, you remember that Bony Boudica had explicitly requested you NOT to board the ship yourself.
+   vntk.msg("", _([[Once the boarding manoeuvre is over, you remember that Bony Boudica had explicitly requested you NOT to board the ship yourself.
 Your mission is a failure.]]))
    misn.finish(false)
 end
@@ -520,7 +536,7 @@ function duchAttacked()
    mem.duchmol:runaway( player.pilot() )
 end
 function duchExploded()
-   vntk.msg("", _([[The final explosion of an hostile ship is always a pleasant sight, isn't it? It is now time to report back to Bony Boudica.]]))
+   vntk.msg("", _([[The final explosion of a hostile ship is always a pleasant sight, isn't it? It is now time to report back to Bony Boudica.]]))
    misn.osdActive(2)
    mem.misn_state = 8
    misn.markerRm( mem.misn_marker )
