@@ -28,7 +28,7 @@ local finish -- Forward-declared functions
 
 mem.osd_desc    = {}
 mem.osd_desc[2] = _("Wait until the coast is clear, then hail one of your wingmates")
-mem.osd_desc[3] = _("Attack Raelid Outpost until it is destroyed")
+mem.osd_desc[3] = _("Attack Fort Raelid until it is destroyed")
 mem.osd_desc[4] = _("Return to FLF base")
 
 function create ()
@@ -43,9 +43,9 @@ end
 
 function accept ()
    if tk.yesno( _("The Next Level"), fmt.f( _([["Hello there, {player}! You're just in time. We were just discussing our next operation against the Dvaered oppressors! Do you want in?"]]), {player=player.name()} ) ) then
-      tk.msg( _("A Decisive Strike"), _([[You take a seat among the group. "Fantastic!" says Benito. "Let me get you caught up, then. Do you remember that mission in Raelid you helped with a while back?" You nod. You were wondering what you were actually creating a diversion from. "Yes, well, I never got around to telling you what we actually did there. See, we've been wanting to destroy Raelid Outpost for some time, mostly because it's often used as a front for trying to scout us out. So while you were getting the attention of those Dvaereds, we rigged a special bomb and covertly installed it onto the outpost!"]]) )
+      tk.msg( _("A Decisive Strike"), _([[You take a seat among the group. "Fantastic!" says Benito. "Let me get you caught up, then. Do you remember that mission in Raelid you helped with a while back?" You nod. You were wondering what you were actually creating a diversion from. "Yes, well, I never got around to telling you what we actually did there. See, we've been wanting to destroy Fort Raelid for some time, mostly because it's often used as a front for trying to scout us out. So while you were getting the attention of those Dvaereds, we rigged a special bomb and covertly installed it onto the outpost!"]]) )
       tk.msg( _("A Decisive Strike"), fmt.f( _([["Now, the bomb is not perfect. Given how hastily we had to install the thing, we could not make it so that it could be detonated remotely. Instead, it has to be detonated manually, by blasting the station repeatedly. Shooting it down, in other words.
-    "So here's the plan. We have hired a large group of pirates to help us out by creating a massive disturbance far away from our target. You are to wait until the coast is clear, then swarm in and attack the outpost with all you've got. You, {player}, will lead the charge. You have to determine the optimal time, when the Dvaereds are far enough away for you to initiate the attack, but before the pirates are inevitably overwhelmed. Simply hail one of the others when it's time to attack, then make a beeline for Raelid Outpost and shoot at it with all you've got!"]]), {player=player.name()} ) )
+    "So here's the plan. We have hired a large group of pirates to help us out by creating a massive disturbance far away from our target. You are to wait until the coast is clear, then swarm in and attack the outpost with all you've got. You, {player}, will lead the charge. You have to determine the optimal time, when the Dvaereds are far enough away for you to initiate the attack, but before the pirates are inevitably overwhelmed. Simply hail one of the others when it's time to attack, then make a beeline for Fort Raelid and shoot at it with all you've got!"]]), {player=player.name()} ) )
       tk.msg( _("A Decisive Strike"), _([["You guys are some of our best pilots, so try not to get killed, eh? A moment of triumph is upon us! Down with the oppressors!" The last line earns Benito a cheer from the crowd. Well, time to get your ship ready for the battle.]]) )
 
       misn.accept()
@@ -53,7 +53,7 @@ function accept ()
       mem.osd_desc[1] = fmt.f( _("Fly to the {sys} system and meet with the group of FLF ships"), {sys=mem.missys} )
       misn.osdCreate( _("Assault on Raelid"), mem.osd_desc )
       misn.setTitle( _("Assault on Raelid") )
-      misn.setDesc( _("Join with the other FLF pilots for the assault on Raelid Outpost.") )
+      misn.setDesc( _("Join with the other FLF pilots for the assault on Fort Raelid.") )
       mem.marker = misn.markerAdd( mem.missys, "plot" )
       misn.setReward( _("A great victory against the Dvaereds") )
 
@@ -90,11 +90,11 @@ function enter ()
 
          local ro, ms, nf
 
-         ro = spob.get( "Raelid Outpost" )
-         ms = spob.get( "Marius Station" )
+         ro = spob.get( "Fort Raelid" )
+         ms = spob.get( "Marius Enclave" )
 
-         -- Spawn Raelid Outpost ship
-         dv_base = pilot.add( "Raelid Outpost", "Dvaered", ro:pos() , nil, {ai="dvaered_norun", naked=true} )
+         -- Spawn Fort Raelid ship
+         dv_base = pilot.add( "Fort Raelid", "Dvaered", ro:pos() , nil, {ai="dvaered_norun", naked=true} )
          dv_base:outfitRm( "all" )
          dv_base:outfitRm( "cores" )
          dv_base:outfitAdd( "Dummy Systems" )
@@ -102,7 +102,7 @@ function enter ()
          dv_base:outfitAdd( "Dummy Engine" )
          dv_base:control()
          dv_base:setNoDisable()
-         dv_base:setNoboard()
+         dv_base:setNoBoard()
          dv_base:setNoLand()
          dv_base:setVisible()
          dv_base:setHilight()
@@ -135,7 +135,7 @@ function enter ()
          end
 
          -- Spawn FLF ships
-         local jmp = jump.get( "Raelid", "Arcanis" )
+         local jmp = jump.get( "Raelid", "Zacron" )
          flf_fleet = fleet.add( 14, "Vendetta", "FLF", jmp:pos() )
 
          for i, j in ipairs( flf_fleet ) do
@@ -293,7 +293,7 @@ end
 
 
 function timer_station ()
-   tk.msg( _("Ominous Foretelling"), _([[As Raelid Outpost erupts into a fantastic explosion before your very eyes, your comrades cheer. But then, you see something odd. Someone is hailing you... an Empire ship? Surely this can't be. Cautiously, you answer. The man whose face comes up on your view screen wastes no time.
+   tk.msg( _("Ominous Foretelling"), _([[As Fort Raelid erupts into a fantastic explosion before your very eyes, your comrades cheer. But then, you see something odd. Someone is hailing you... an Empire ship? Surely this can't be. Cautiously, you answer. The man whose face comes up on your view screen wastes no time.
     "So, you actually showed your face. I half expected you to run away and hide. But no matter." You try not to show any reaction to his icy stare. He continues.]]) )
    tk.msg( _("Ominous Foretelling"), _([["Terrorist, I'd bet you think this latest act of yours is a victory for you. Perhaps, for now, it is. But I assure you that the Empire will not ignore your activities any longer. I have already sent word to the Emperor, and he has authorized a declaration of your organization, the FLF, as an enemy of the Empire. Count the minutes on your fingers, terrorist. Your days are numbered."
     The Empire officer then immediately ceases communication, and you suddenly feel a chill down your spine. But one of your wingmates snaps you out of it. "Pay the Empire no mind," he says. "More importantly, we have to get out of here! We'll meet you at Sindbad."]]) )
@@ -333,7 +333,7 @@ function finish ()
    player.pay( mem.credits )
    flf.setReputation( 70 )
    faction.get("FLF"):modPlayer( mem.reputation )
-   flf.addLog( _([[You led the effort to destroy the hated Dvaered base, Raelid Outpost, a major victory for the FLF. This act led to the Empire listing you and the FLF as an enemy of the Empire.]]) )
+   flf.addLog( _([[You led the effort to destroy the hated Dvaered base, Fort Raelid, a major victory for the FLF. This act led to the Empire listing you and the FLF as an enemy of the Empire.]]) )
    misn.finish( true )
 end
 
