@@ -1,17 +1,15 @@
 --[[
 <?xml version='1.0' encoding='utf8'?>
 <mission name="FLF Commodity Run">
-  <avail>
-   <priority>5</priority>
-   <cond>var.peek("commodity_runs_active") == nil or var.peek("commodity_runs_active") &lt; 3</cond>
-   <chance>90</chance>
-   <location>Computer</location>
-   <faction>FLF</faction>
-  </avail>
-  <notes>
+ <priority>5</priority>
+ <cond>var.peek("commodity_runs_active") == nil or var.peek("commodity_runs_active") &lt; 3</cond>
+ <chance>90</chance>
+ <location>Computer</location>
+ <faction>FLF</faction>
+ <notes>
    <done_misn name="Deal with the FLF agent"/>
-  </notes>
- </mission>
+ </notes>
+</mission>
  --]]
 --[[
 
@@ -20,7 +18,7 @@
 --]]
 require "missions.neutral.commodity_run"
 
--- luacheck: globals cargo_land commchoices (from base mission neutral.commodity_run)
+-- luacheck: globals cargo_land commchoices (inheriting variables, TODO get rid of)
 
 mem.misn_title = _("FLF: {cargo} Supply Run")
 mem.misn_desc = _("There is a need to supply {pnt} with more {cargo}. Find a planet where you can buy this commodity and bring as much of it back as possible.")
