@@ -47,7 +47,7 @@ local oldman_portrait = "old_man.png"
 local oldman_image = "old_man.png"
 
 local mainsys = system.get("Limbo")
-local searchsys = system.get("Doeston")
+local searchspob, searchsys = spob.getS("Cerberus Outpost")
 local cutscenesys = system.get("Arandon")
 local stealthsys = system.get("Zerantix")
 -- Mission states:
@@ -95,7 +95,7 @@ end
 
 
 function generate_npc ()
-   if spob.cur() == spob.get("Cerberus") then
+   if spob.cur() == searchspob then
       misn.npcAdd( "approach_oldman", _("Old Man"), oldman_portrait, _("You see a nonchalant old man sipping on his drink with a carefree aura.") )
       if mem.misn_state==3 or mem.misn_state==4 or mem.bribed_scavengers==true then
          misn.npcAdd( "approach_scavengers", minerva.scavengers.name, minerva.scavengers.portrait, minerva.scavengers.description )
@@ -203,13 +203,13 @@ She starts eating the parfait, which seems to be larger than her head.]]))
    maikki(_([["My mother died without telling me, but, after her death, while going through her stuff, I found out that my father was the famous Kex McPherson!"]]))
    maikki(_([["Apparently, one day he went into the nebula with his business partner Mireia and they were never seen again. All attempts to find them failed."]]))
    maikki(_([["Most people believe they are dead, but I think he was kidnapped and is being held here. Maybe he hit his head and even forgot who he was!"]]))
-   maikki(_([["I don't have a spaceship, but while I look around here, could you try to look for hints around where he went missing? I heard he was very fond of the Cerberus bar in Doeston. Maybe there is a hint there."]]))
+   maikki(_([["I don't have a spaceship, but while I look around here, could you try to look for hints around where he went missing? I heard he was very fond of the Cerberus Outpost bar in Doeston. Maybe there is a hint there."]]))
    vn.func( function ()
       if mem.misn_state < 0 then
          mem.misn_state = 0
          misn.osdCreate( _("Finding Maikki's Father"),
-            { fmt.f(_("Look around the {sys} system"), {sys=searchsys}) } )
-         mem.misn_marker = misn.markerAdd( searchsys, "low" )
+            { fmt.f(_("Look around {spb} ({sys} system)"), {spb=searchspob, sys=searchsys}) } )
+         mem.misn_marker = misn.markerAdd( searchspob, "low" )
          minerva.log.maikki(_("You were told her father could be near Doeston.") )
       end
    end )
@@ -354,9 +354,9 @@ function approach_scavengers ()
    vn.clear()
    vn.scene()
    local scavA = vn.newCharacter( minerva.scavengera.name,
-         { image=minerva.scavengera.image, color=minerva.scavengera.colour, pos="left" } )
+         { image=minerva.scavengera.image, colour=minerva.scavengera.colour, pos="left" } )
    local scavB = vn.newCharacter( minerva.scavengerb.name,
-         { image=minerva.scavengerb.image, color=minerva.scavengerb.colour, pos="right" } )
+         { image=minerva.scavengerb.image, colour=minerva.scavengerb.colour, pos="right" } )
    vn.transition()
 
    if mem.bribed_scavengers==true then
@@ -503,7 +503,7 @@ function cutscene_hail ()
    vn.scene()
    local scavB = vn.newCharacter( _("Scavenger"),
          { image=minerva.scavengerb.image,
-         color=minerva.scavengerb.colour, shader=love_shaders.hologram{strength=2.0} } )
+         colour=minerva.scavengerb.colour, shader=love_shaders.hologram{strength=2.0} } )
    vn.transition("electric")
    vn.na(_("The comm flickers as a scavenger appears into view. He looks a bit pale."))
    scavB(_([["Thank you. I thought I was a goner. My sensors failed me at the worst time and it's impossible to see shit in this nebula."]]))
@@ -630,10 +630,10 @@ end
 function stealthheartbeat ()
    local pp = player.pilot()
    local dist= math.min ( pscavA:pos():dist(pp:pos()), pscavB:pos():dist(pp:pos()) )
-   if not pp:flags("stealth") and dist < 1000 / (1+pp:shipstat("ew_hide")/100) then
+   if not pp:flags("stealth") and dist < 1000 * pp:shipstat("ew_hide",true) then
       if mem.stealthfailing==nil then
          mem.stealthfailing = 0
-         player.msg( _("#rYou are about to be discovered!"), true )
+         player.msg( "#r".._("You are about to be discovered!"), true )
       end
       mem.stealthfailing = mem.stealthfailing+1
       if mem.stealthfailing > 6 then
@@ -643,14 +643,14 @@ function stealthheartbeat ()
             p:taskClear()
             p:hyperspace( cutscenesys )
          end
-         player.msg( _("#rYou have been detected! Stealth failed!"), true )
+         player.msg( "#r".._("You have been detected! Stealth failed!"), true )
          hook.rm( stealthbroadcasthook )
          return
       end
-   elseif dist > 2000 * (1+pp:shipstat("ew_detect")/100) then
+   elseif dist > 2000 * pp:shipstat("ew_detect",true) then
       if mem.stealthfailing==nil then
          mem.stealthfailing = 0
-         player.msg( _("#rYou are about to lose track of the scavengers!!"), true )
+         player.msg( "#r".._("You are about to lose track of the scavengers!!"), true )
       end
       mem.stealthfailing = mem.stealthfailing+1
       if mem.stealthfailing > 6 then
@@ -659,7 +659,7 @@ function stealthheartbeat ()
          if wreck ~= nil then
             wreck:rm()
          end
-         player.msg( _("#rYou lost track of the scavengers! Stealth failed!"), true )
+         player.msg( "#r".._("You lost track of the scavengers! Stealth failed!"), true )
          hook.rm( stealthbroadcasthook )
          return
       end
@@ -762,10 +762,10 @@ function scavengers_encounter ()
    vn.scene()
    local scavA = vn.newCharacter( minerva.scavengera.name,
          { image=minerva.scavengera.image,
-         color=minerva.scavengera.colour, shader=love_shaders.hologram{strength=2.0}, pos="left" } )
+         colour=minerva.scavengera.colour, shader=love_shaders.hologram{strength=2.0}, pos="left" } )
    local scavB = vn.newCharacter( minerva.scavengerb.name,
          { image=minerva.scavengerb.image,
-         color=minerva.scavengerb.colour, shader=love_shaders.hologram{strength=2.0}, pos="right" } )
+         colour=minerva.scavengerb.colour, shader=love_shaders.hologram{strength=2.0}, pos="right" } )
    vn.transition("electric")
 
    vn.na(_("Two angry scavengers appear on your screen."))
