@@ -16,6 +16,8 @@
 --[[
    Destroy Za'lek hacking station
 
+   TODO probably should be changed from Gammacron to Fried system
+
    This mission has two ways of being done:
    1. Using brute force and killing everything.
    2. Using stealth if the player boards the drone controllers or hacking center, they can disable drones.
@@ -141,7 +143,7 @@ She grins at you.]]), {sys=mainsys}))
    vn.menu( function ()
       local opts = {
          {_("Ask about the job"), "job"},
-         {_("Are you pirates?"), "pirate"},
+         {_([["Are you pirates?"]]), "pirate"},
          {_("Leave"), "leave"},
       }
       return opts
@@ -251,7 +253,7 @@ function enter ()
       dc:setVisplayer(true)
       dc:setHilight(true)
       -- Controllers can't detect anything
-      dc:intrinsicSet( "ew_hide", -75 )
+      dc:intrinsicSet( "ew_hide", 300 )
       dc:intrinsicSet( "ew_detect", -1000 )
       -- Much more bulky than normal
       dc:intrinsicSet( "shield", 500 )
@@ -274,7 +276,7 @@ function enter ()
    local function spawn_drone( shipname, pos )
       local p = pilot.add( shipname, "Za'lek", fuzz_pos(pos) )
       -- We are nice and make the drones easier to see for this mission
-      p:intrinsicSet( "ew_hide", -50 )
+      p:intrinsicSet( "ew_hide", 100 )
       table.insert( all_ships, p )
       return p
    end
