@@ -46,9 +46,9 @@ function create ()
    mem.tier = rnd.rnd(1,3)
 
    -- Inclusive claiming, multiple missions can be done at the same time!
-   if not misn.claim( returnsys, false, true ) then misn.finish( false ) end
+   if not misn.claim( returnsys, true ) then misn.finish( false ) end
 
-   mem.destpnt, mem.destsys, mem.numjumps, mem.traveldist = car.calculateRoute( rnd.rnd(3,5)+mem.tier, true )
+   mem.destpnt, mem.destsys, mem.numjumps, mem.traveldist = car.calculateRoute( rnd.rnd(3,5)+mem.tier, {always_available=true} )
    if not mem.destpnt then
       misn.finish(false)
       return
@@ -64,7 +64,7 @@ function create ()
    end
    misn.setTitle( fmt.f(_("#oANTLEJOS:#0 {adj} delivery of supplies from {pnt} ({sys} system)"),
          {adj=adj, pnt=mem.destpnt, sys=mem.destsys}) )
-   misn.setReward( fmt.credits(mem.reward) )
+   misn.setReward(mem.reward)
 
    local desc = fmt.f(_("Pick up {cargo} at {pnt} in the {sys} system and bring them to {retpnt} to further accelerate the terraforming. Note that protestors from the PUAAA are expected to show up.\n"),
       {cargo=cargo_name, pnt=mem.destpnt, sys=mem.destsys, retpnt=returnpnt})
@@ -133,7 +133,7 @@ function land ()
       local level = ant.unidiffLevel()
       local total = ant.supplied_total()
       for l = 1,#levelup do
-         if level < l and total > levelup[l] then
+         if level < l and total >= levelup[l] then
             -- TODO better messages
             vntk.msg(_("Terraforming Progress"),_("Through the new supplies and volunteers, Antlejos V has been able to expand its facilities."))
             ant.unidiff( ant.unidiff_list[level+1] )
