@@ -5,14 +5,7 @@
  <chance>960</chance>
  <location>Computer</location>
  <cond>
-   local f = spob.cur():faction()
-   if f then
-      local ft = f:tags()
-      if ft.generic or ft.misn_cargo then
-         return true
-      end
-   end
-   return false
+  require("misn_test").cargo()
  </cond>
  <notes>
   <tier>1</tier>
@@ -89,7 +82,7 @@ function create()
          {pnt=mem.destplanet, sys=mem.destsys, tonnes=fmt.tonnes_short(mem.amount)} ) )
    misn.markerAdd(mem.destplanet, "computer")
    car.setDesc( fmt.f( misn_desc[mem.tier], {cargo=_(mem.cargo), amount=fmt.tonnes(mem.amount), pnt=mem.destplanet, sys=mem.destsys} ), mem.cargo, mem.amount, mem.destplanet, nil, piracyrisk )
-   misn.setReward( fmt.credits(mem.reward) )
+   misn.setReward(mem.reward)
 end
 
 -- Mission is accepted
@@ -109,16 +102,14 @@ end
 
 -- Land hook
 function land()
-   if spob.cur() == mem.destplanet then
-      -- Semi-random message.
-      lmisn.sfxMoney()
-      vntk.msg( _("Delivery success!"), fmt.f(cargo_land[rnd.rnd(1, #cargo_land)], {cargo=_(mem.cargo), credits=fmt.credits(mem.reward)}) )
-      player.pay(mem.reward)
-      pir.reputationNormalMission(rnd.rnd(2,3))
-      misn.finish(true)
+   if spob.cur() ~= mem.destplanet then
+      return
    end
-end
 
-function abort ()
-   misn.finish(false)
+   -- Semi-random message.
+   lmisn.sfxMoney()
+   vntk.msg( _("Delivery success!"), fmt.f(cargo_land[rnd.rnd(1, #cargo_land)], {cargo=_(mem.cargo), credits=fmt.credits(mem.reward)}) )
+   player.pay(mem.reward)
+   pir.reputationNormalMission(rnd.rnd(2,3))
+   misn.finish(true)
 end
