@@ -49,7 +49,9 @@ function create ()
    vn.label("refuse")
    vn.na(_("You refuse to help them and leave them to the mercy of the stars."))
 
-   der.addMiscLog(fmt.f(_([[You refused to rescue the crew of a derelict ship and left them to float in {sys}.]]), {sys=system.cur()}))
+   vn.func( function ()
+      der.addMiscLog(fmt.f(_([[You refused to rescue the crew of a derelict ship and left them to float in {sys}.]]), {sys=system.cur()}))
+   end )
 
    vn.sfx( der.sfx.unboard )
    vn.done()
@@ -74,7 +76,7 @@ function create ()
 
    misn.setTitle(_("Derelict Rescue"))
    misn.setDesc(fmt.f(_("You have agreed to take some crew you rescued from a derelict ship to {pnt} in the {sys} system."), {pnt=mem.destpnt, sys=mem.destsys}))
-   misn.setReward(fmt.credits(mem.reward_amount))
+   misn.setReward(mem.reward_amount)
 
    local c = commodity.new( N_("Rescued Crew"), N_("Some crew you rescued from a derelict ship.") )
    mem.civs = misn.cargoAdd( c, 0 )
@@ -93,6 +95,7 @@ function land ()
 
    vn.clear()
    vn.scene()
+   vn.transition()
    vn.sfxMoney()
    vn.func( function ()
       player.pay( mem.reward_amount )
