@@ -8,6 +8,9 @@
  <faction>Dvaered</faction>
  <faction>Empire</faction>
  <faction>Goddard</faction>
+ <cond>
+   return require("misn_test").reweight_active()
+ </cond>
  <notes>
   <tier>2</tier>
  </notes>
@@ -25,8 +28,12 @@
 local pir = require "common.pirate"
 local fmt = require "format"
 local neu = require "common.neutral"
+local portrait = require "portrait"
+local vn = require "vn"
 
 local credits = 750e3
+local reward = outfit.get("Satellite Mock-up")
+local cargo_space = 3
 local launchSatellite -- Forward-declared functions
 
 local articles = {
@@ -37,6 +44,10 @@ local articles = {
    }
 }
 
+local npc_name = _("Scientists")
+local npc_portrait = "neutral/unique/neil.webp"
+local npc_image = portrait.getFullPath( npc_portrait )
+
 function create ()
    -- Note: this mission does not make any system claims.
    -- Set up mission variables
@@ -48,43 +59,62 @@ function create ()
    mem.satellite_sys = system.get("Arandon") -- Not too unstable
 
    -- Set stuff up for the spaceport bar
-   misn.setNPC( _("Scientists"), "neutral/unique/neil.webp", _("A bunch of scientists seem to be chattering nervously among themselves.") )
-
+   misn.setNPC( npc_name, npc_portrait, _("A bunch of scientists seem to be chattering nervously among themselves.") )
 end
 
 
 function accept ()
-   -- See if rejects mission
-   if not tk.yesno( _("Bar"), _([[You approach the scientists. They seem a bit nervous and one mutters something about whether it's a good idea or not. Eventually one of them comes up to you.
-    "Hello Captain, we're looking for a ship to take us into the Sol Nebula. Would you be willing to take us there?"]]) ) then
-      return
-   end
+   local accepted = false
 
-   -- Check for cargo space
-   if player.pilot():cargoFree() <  3 then
-      tk.msg( _("Bar"), _([["You do not have enough free cargo space to accept this mission!"]]) )
-      return
-   end
+   vn.clear()
+   vn.scene()
+   local sci = vn.newCharacter( npc_name, {image=npc_image} )
+   vn.transition()
+   sci(_([[You approach the scientists. They seem a bit nervous and one mutters something about whether it's a good idea or not. Eventually one of them comes up to you.
+"Hello Captain, we're looking for a ship to take us into the Sol Nebula. Would you be willing to take us there?"]]))
+   vn.menu{
+      {_([[Accept]]), "accept"},
+      {_([[Refuse]]), "refuse"},
+   }
+
+   vn.label("refuse")
+   vn.done()
+
+   vn.label("nospace")
+   vn.na(fmt.f(_([["You need an additional {space} of free cargo space to accept this mission!"]]),
+      {space=cargo_space - player.pilot():cargoFree()}))
+   vn.done()
+
+   vn.label("accept")
+   vn.func( function ()
+      if player.pilot():cargoFree() < cargo_space then
+         vn.jump("nospace")
+         return
+      end
+      accepted = true
+   end )
+   vn.na(fmt.f(_([["We had a trip scheduled with a space trader, but they backed out at the last minute. So we were stuck here until you came. We've got a research probe that we want to release into the {sys} system to monitor the Nebula's growth rate. The probe launch procedure is pretty straightforward and shouldn't have any complications."
+He takes a deep breath, "We hope to be able to find out more secrets of the Sol Nebula so mankind can once again regain its lost heritage. So far, the radiation and volatility of the deeper areas haven't been very kind to our instruments. That's why we designed this probe we're going to launch."]]),
+      {sys=mem.satellite_sys}))
+   vn.na(fmt.f(_([["The plan is for you to take us to {sys} so we can launch the probe, and then return us to our home at {home_pnt} in the {home_sys} system. If all goes well, the probe will automatically send us the data we need. You'll be paid {credits} when we arrive."]]),
+      {sys=mem.satellite_sys, home_pnt=mem.homeworld, home_sys=mem.homeworld_sys, credits=fmt.credits(credits)}))
+   vn.run()
+
+   if not accepted then return end
 
    -- Add cargo
    local c = commodity.new( N_("Satellite"), N_("A small space probe loaded with sensors for exploring the depths of the nebula.") )
-   mem.cargo = misn.cargoAdd( c, 3 )
+   mem.cargo = misn.cargoAdd( c, cargo_space )
 
    -- Set up mission information
    misn.setTitle( _("Nebula Satellite") )
-   misn.setReward( fmt.credits(credits) )
+   misn.setReward(credits)
    misn.setDesc( fmt.f( _("Go to the {sys} system to launch the probe."), {sys=mem.satellite_sys} ) )
    mem.misn_marker = misn.markerAdd( mem.satellite_sys, "low" )
 
    -- Add mission
    misn.accept()
 
-   -- More flavour text
-   tk.msg( _("Scientific Exploration"), fmt.f(_([["We had a trip scheduled with a space trader, but they backed out at the last minute. So we were stuck here until you came. We've got a research probe that we want to release into the {sys} system to monitor the Nebula's growth rate. The probe launch procedure is pretty straightforward and shouldn't have any complications."
-    He takes a deep breath, "We hope to be able to find out more secrets of the Sol Nebula so mankind can once again regain its lost heritage. So far, the radiation and volatility of the deeper areas haven't been very kind to our instruments. That's why we designed this probe we're going to launch."]]), {sys=mem.satellite_sys}) )
-   tk.msg( _("Scientific Exploration"), fmt.f(_([["The plan is for you to take us to {sys} so we can launch the probe, and then return us to our home at {home_pnt} in the {home_sys} system. If all goes well, the probe will automatically send us the data we need. You'll be paid {credits} when we arrive."]]), {sys=mem.satellite_sys,
-         home_pnt=mem.homeworld, home_sys=mem.homeworld_sys, credits=fmt.credits(credits)} ) )
-
    misn.osdCreate(_("Nebula Satellite"), {fmt.f(_("Go to the {sys} system to launch the probe."), {sys=mem.satellite_sys})})
    -- Set up hooks
    hook.land("land")
@@ -96,10 +126,18 @@ function land ()
    mem.landed = spob.cur()
    -- Mission success
    if mem.misn_stage == 1 and mem.landed == mem.homeworld then
-      tk.msg( _("Mission Success"), _([[The scientists thank you for your help before going back to their home to continue their nebula research. As a keepsake, one of them gives you a mock-up of the probe you helped them launch.]]) )
-      player.outfitAdd( "Satellite Mock-up" )
+      vn.clear()
+      vn.scene()
+      vn.transition()
+      vn.na(_([[The scientists thank you for your help before going back to their home to continue their nebula research. As a keepsake, one of them gives you a mock-up of the probe you helped them launch.]]) )
+      vn.sfxVictory()
+      vn.func( function ()
+         player.outfitAdd( reward )
+         player.pay( credits )
+      end )
+      vn.na(fmt.reward(credits).."\n"..fmt.reward(reward))
+      vn.run()
       pir.reputationNormalMission(rnd.rnd(2,3))
-      player.pay( credits )
       neu.addMiscLog( _([[You helped a group of scientists launch a research probe into the Nebula.]]) )
       misn.finish(true)
    end
