@@ -4,14 +4,14 @@ local vni = require "vnimage"
 local tut = require "common.tutorial"
 local poi = require "common.poi"
 
-local reward = outfit.get("Veil of Penelope")
+local misnvar = "poi_proteron_agent"
 
 return function ( mem )
    -- Must be locked
    if not mem.locked then return end
 
    -- Already done
-   if player.numOutfit( reward ) > 0 then
+   if var.peek( misnvar ) then
       return
    end
 
@@ -20,9 +20,9 @@ return function ( mem )
       ship = "Proteron Gauss",
       func = function ()
          if faction.known( "Proteron" ) then
-            vn.na(_([[You enter the ship and make way to the bridge. The entire ship is oddly quiet as you pass through, with no signs of life. You reach the bridge and find the ship's systems have just enough energy left to power up, letting you jack in.]]))
+            vn.na(_([[You enter the derelict and make way to the bridge. The entire ship is oddly quiet as you pass through, with no signs of life. You reach the bridge and find the ship's systems have just enough energy left to power up, letting you jack in.]]))
          else
-            vn.na(_([[You enter the ship enter the derelict, which is of a make you do not fully recognize, and make way to the bridge. The entire ship is oddly quiet as you pass through, with no signs of life. You reach the bridge and find the ship's systems have just enough energy left to power up, letting you jack in.]]))
+            vn.na(_([[You enter the derelict, which is of a make you do not fully recognize, and make way to the bridge. The entire ship is oddly quiet as you pass through, with no signs of life. You reach the bridge and find the ship's systems have just enough energy left to power up, letting you jack in.]]))
          end
 
          local sai = tut.vn_shipai()
@@ -33,8 +33,8 @@ return function ( mem )
          vn.disappear( sai, tut.shipai.transition )
 
          vn.scene()
-         local v01 = vn.newCharacter( vni.soundonly( _("01"), {color={0.9,0.2,0.2}, pos="left"} ) )
-         local v02 = vn.newCharacter( vni.soundonly( _("02"), {color={0.4,0.2,0.9}, pos="right"} ) )
+         local v01 = vn.newCharacter( vni.soundonly( _("01"), {colour={0.9,0.2,0.2}, pos="left"} ) )
+         local v02 = vn.newCharacter( vni.soundonly( _("02"), {colour={0.4,0.2,0.9}, pos="right"} ) )
          vn.transition()
 
          local function noise ()
@@ -60,7 +60,7 @@ return function ( mem )
          v02(_([["When is the strike planned?"]]))
          v01(_([["Do not get ahead of yourself agent. The Leaders are the only ones who can know. Just make sure you are prepared to take action when the motion starts."]]))
          v02(_([["Understood."]]))
-         vn.na(_([[END  OF AUDIO DATA ##2969]]))
+         vn.na(_([[END OF AUDIO DATA ##2969]]))
 
          vn.disappear( v01 )
 
@@ -70,7 +70,7 @@ return function ( mem )
          v02(fmt.f(_([["…possibly end of civilization. The little functionality left in my scanners has not picked up any objects, just this dense fog or whatever… {n1}"]]),
             {n1=noise()}))
          v02(_([["…rations will not last much longer. I just hope that was just part of the plan, if not all my work will have been in vain.""]]))
-         vn.na(_([[END  OF AUDIO DATA ##4189]]))
+         vn.na(_([[END OF AUDIO DATA ##4189]]))
 
          vn.disappear( v02 )
 
@@ -85,13 +85,15 @@ return function ( mem )
          sai(_([["I see. Maybe you should continue exploring the ship. There might be something of use that the ship scanner has not been able to pick up."]]))
          vn.disappear( sai, tut.shipai.transition )
 
-         vn.na(fmt.f(_([[Following {shipai}'s advice, you continue to explore the ship and eventually reach the systems room. You notice there seems to be a device interfering with the radiation emitted. You can't tell who made it, but it seems that it was likely the main reason that the derelict was so hard to find. You manage to dislodge it to take it back to your ship for further analysis.]]),{shipai=tut.ainame()}))
-
+         local reward = poi.data_str(1)
+         vn.na(fmt.f(_([[Following {shipai}'s advice, you continue to explore the ship and eventually reach the systems room. Going over the systems, it seems like you can recover {reward}, which you promptly do so.]]),
+            {shipai=tut.ainame(), reward=reward}))
          vn.na(fmt.reward(reward))
 
          vn.func( function ()
-            player.outfitAdd( reward )
-            poi.log(fmt.f(_([[You found a derelict ship in the {sys} system with corrupted information about an agent. You also were able to find a strange device called {reward} from the ship.]]),
+            var.push( misnvar, true )
+            poi.data_give(1)
+            poi.log(fmt.f(_([[You found a derelict ship in the {sys} system with corrupted information about an agent. You also were able to recover {reward} from the ship.]]),
                {sys=mem.sys, reward=reward}))
          end )
       end,
