@@ -8,7 +8,8 @@
    if not f or not f:tags().generic then
       return false
    end
-   if scur:tags().station then
+   local st = scur:tags()
+   if st.station or st.poor or st.refugee then
       return false
    end
    local sindep = system.cur():presences()["Independent"] or 0
@@ -85,6 +86,14 @@ function create ()
    if not misn.claim( mem.missys ) then misn.finish( false ) end
 
    local planets = mem.missys:spobs()
+   local newplanets = {}
+   for k,v in ipairs(planets) do
+      if (v:tags().nosightseeing ~= true) then
+         table.insert( newplanets, v )
+      end
+   end
+   planets = newplanets
+
    local numpoints = rnd.rnd( 2, #planets )
    mem.attractions = numpoints
    mem.points = {}
@@ -126,7 +135,7 @@ function create ()
 #nAttractions:#0 {amount}
 #nPreferred Ship:#0 Luxury Yacht-class]]),
       {sys=mem.missys, amount=mem.attractions, retspob=mem.startingplanet, retsys=mem.startingsystem} ) )
-   misn.setReward( fmt.credits( mem.credits ) )
+   misn.setReward( mem.credits )
    mem.marker = misn.markerAdd( mem.missys, "computer" )
 end
 
@@ -135,7 +144,7 @@ function accept ()
    if not player.pilot():ship():tags().luxury then
       if vntk.yesno( _("Not Very Luxurious"), fmt.f( _("Since your ship is not a Luxury Yacht-class ship, you will only be paid {credits}. Accept the mission anyway?"), {credits=fmt.credits(mem.credits_nolux)} ) ) then
          mem.nolux_known = true
-         misn.setReward( fmt.credits( mem.credits_nolux ) )
+         misn.setReward( mem.credits_nolux )
       else
          return
       end
