@@ -12,6 +12,9 @@
  <faction>Independent</faction>
  <faction>FLF</faction>
  <done>Pirate Hit Intro</done>
+ <tags>
+  <tag>pir_cap_ch01_med</tag>
+ </tags>
 </mission>
 --]]
 --[[
@@ -37,6 +40,35 @@ misn_title[4] = _("Big Assassination Job in {sys}")
 misn_title[5] = _("Dangerous Assassination Job in {sys}")
 misn_title[6] = _("Highly Dangerous Assassination Job in {sys}")
 
+-- Reasons
+local reason_list = {
+   _(" for excessive amounts of pineapple on pizza"),
+   _(" for messing with 'the business'"),
+   _(" for cozying up to the wrong pirate clans"),
+   _(" for increasing their bribe fees"),
+   _(" for being too nosy"),
+   _(" for winning in blackjack"),
+   _(" for being a beacon of order and peace"),
+   _(" for thwarting piracy"),
+   _(" for not respecting the pirate code"),
+   _(" for throwing out pineapple pizza"),
+   _(" for being a tool of bourgeoisie oppression"),
+   _(" for putting fellow pirates in prison"),
+   _(" for being an asshole"),
+   _(" for taking a Pirate Lord's landing spot"),
+   _(" for abandoning a pet cat"),
+   _(" for using pirates as scapegoats in insurance fraud and not giving a cut of the share"),
+   _(" for disrespecting poor people"),
+   _(" for fomenting class warfare"),
+   _(" for not respecting human freedom"),
+   _(" for just being a piece of shit human"),
+   _(" for spitting sunflower seeds on the space station floor"),
+   _(" for not properly recycling their garbage"),
+   _(" for hosting a lame party"),
+   _(" for raising tariffs on cheese imports"),
+   _(" for making fun of the space pirate shanty"),
+}
+
 local hunters = {}
 local hunter_hits = {}
 
@@ -59,7 +91,7 @@ function create ()
       "Sirius",
       "Soromid",
       "Trader",
-      "Traders Guild",
+      "Traders Society",
       "Za'lek",
    }
 
@@ -80,7 +112,7 @@ function create ()
    end
 
    mem.missys = systems[ rnd.rnd( 1, #systems ) ]
-   if not misn.claim( mem.missys, false, true ) then misn.finish( false ) end
+   if not misn.claim( mem.missys, true ) then misn.finish( false ) end
 
    mem.target_faction = nil
    while mem.target_faction == nil and #target_factions > 0 do
@@ -106,10 +138,22 @@ function create ()
    mem.level = level_setup()
    mem.pship, mem.credits, mem.reputation = bounty_setup()
 
+   -- Get reason
+   local reason = reason_list[ rnd.rnd(1,#reason_list) ]
+
    -- Set mission details
    misn.setTitle( fmt.f( pir.prefix(mem.paying_faction)..misn_title[mem.level], {sys=mem.missys} ) )
 
-   local mdesc = fmt.f( _("A meddlesome {fct} pilot known as {plt} was recently seen in the {sys} system. Local crime lords want this pilot dead. {plt} is known to be flying a {shipclass}-class ship. The pilot may disappear if you take too long to reach the {sys} system.{msg}"), {fct=_(mem.target_faction), plt=mem.name, sys=mem.missys, shipclass=_(ship.get(mem.pship):classDisplay()), msg=faction_text } )
+   local mdesc = fmt.f( _([[A meddlesome {fct} pilot known as {plt} was recently seen in the {sys} system. Local crime lords want this pilot dead{reason}. {plt} is known to be flying a {shipclass}-class ship. The pilot may disappear if you take too long to reach the {sys} system.{msg}
+
+#nTarget:#0 {plt} ({shipclass}-class ship)
+#nWanted:#0 Dead
+#nLast Seen:#0 {sys} system]]),
+      {fct=_(mem.target_faction), plt=mem.name, sys=mem.missys, shipclass=_(ship.get(mem.pship):classDisplay()), msg=faction_text, reason=reason } )
+   if pir.factionIsClan(mem.paying_faction) then
+      mdesc = mdesc.."\n"..fmt.f(_([[#nReputation Gained:#0 {fct}]]),
+         {fct=mem.paying_faction})
+   end
    if not pir.factionIsPirate( spob.cur():faction() ) then
       -- We're not on a pirate stronghold, so include a clear warning that the
       -- mission is in fact illegal.
@@ -117,7 +161,7 @@ function create ()
    end
    misn.setDesc( mdesc )
 
-   misn.setReward( fmt.credits( mem.credits ) )
+   misn.setReward( mem.credits )
    mem.marker = misn.markerAdd( mem.missys, "computer" )
 end
 
@@ -247,7 +291,7 @@ function level_setup ()
    local level
    if mem.target_faction == "Independent" then
       level = 1
-   elseif mem.target_faction == "Trader" or mem.target_faction == "Traders Guild" then
+   elseif mem.target_faction == "Trader" or mem.target_faction == "Traders Society" then
       if num_pirates <= 100 then
          level = rnd.rnd( 1, 2 )
       else
@@ -514,7 +558,7 @@ function bounty_setup ()
          credits = 1e6 + rnd.sigma() * 100e3
          reputation = 8
       end
-   elseif mem.target_faction == "Traders Guild" then
+   elseif mem.target_faction == "Traders Society" then
       if mem.level == 1 then
          if rnd.rnd() < 0.5 then
             pship = "Gawain"
@@ -589,17 +633,19 @@ function succeed ()
    player.pay( mem.credits )
 
    -- Pirate rep cap increase
-   local bounty_done = var.peek( "pir_bounty_done" )
+   --local bounty_done = var.peek( "pir_bounty_done" )
    var.push( "pir_bounty_done", true )
+   --[[
    if bounty_done ~= true then
       pir.modReputation( 5 )
    end
+   --]]
 
    if mem.level >= 5 then
       local bounty_dangerous_done = var.peek( "pir_bounty_dangerous_done" )
       var.push( "pir_bounty_dangerous_done", true )
       if not bounty_dangerous_done then
-         pir.modReputation( 2 )
+         --pir.modReputation( 2 )
          pir.modDecayFloor( 2 )
       end
 
@@ -607,7 +653,7 @@ function succeed ()
          local bounty_highly_dangerous_done = var.peek( "pir_bounty_highly_dangerous_done" )
          var.push( "pir_bounty_highly_dangerous_done", true )
          if not bounty_highly_dangerous_done then
-            pir.modReputation( 3 )
+            --pir.modReputation( 3 )
             pir.modDecayFloor( 3 )
          end
       end
