@@ -3,7 +3,7 @@
 <mission name="Pirate Hit Intro">
  <unique />
  <priority>3</priority>
- <cond>player.numOutfit("Mercenary License") &gt; 0 or spob.cur():blackmarket() or spob.cur():tags().criminal ~= nil</cond>
+ <cond>player.outfitNum("Mercenary License") &gt; 0 or spob.cur():blackmarket() or spob.cur():tags().criminal ~= nil</cond>
  <chance>100</chance>
  <location>Bar</location>
  <faction>Wild Ones</faction>
@@ -15,6 +15,9 @@
  <notes>
   <tier>3</tier>
  </notes>
+ <tags>
+  <tag>pir_cap_ch01_lrg</tag>
+ </tags>
 </mission>
 --]]
 --[[
@@ -28,7 +31,7 @@ local fmt = require "format"
 local pilotname = require "pilotname"
 local lmisn = require "lmisn"
 local vn = require "vn"
-local portrait = require "portrait"
+local vni = require "vnimage"
 
 local spawn_target -- Forward-declared functions
 
@@ -39,8 +42,7 @@ local target_faction = "Independent"
 local reward = 450e3
 
 local givername = _("Shady Individual")
-mem.giverportrait = portrait.get()
-mem.giverimage = portrait.getFullPath(mem.giverportrait)
+mem.giverimage, mem.giverportrait = vni.generic()
 
 function create ()
    -- Lower probability on non-pirate places
@@ -122,7 +124,7 @@ They grin.]]),
 
    misn.setDesc( fmt.f( _("A pilot known as {plt}, recently seen in the {sys} system, has to be eliminated as compensation for some unknown clients."), {plt=mem.name, sys=mem.missys } ) )
 
-   misn.setReward( fmt.credits( reward ) )
+   misn.setReward( reward )
    mem.marker = misn.markerAdd( mem.missys )
 
    misn.osdCreate( _("Dark Compensation"), {
@@ -255,7 +257,5 @@ They grin and then fade into the shadows.]]))
 
    pir.addMiscLog(_("You performed a 'hit' on a debt-ridden pilot for some unknown clients. They were satisfied with your job and this opened up more similar missions at the mission computer."))
 
-   -- Pirate rep cap increase
-   pir.modReputation( 5 )
    misn.finish( true )
 end
