@@ -25,12 +25,15 @@ local pilotname = require "pilotname"
 local fmt = require "format"
 local shark = require "common.shark"
 local lmisn = require "lmisn"
+local vn = require "vn"
+local vntk = require "vntk"
 
 local baddie -- Non-persistent state
 
 -- Mission constants
 local paypla, paysys = spob.getS("Darkshed")
 
+local reward_outfit = outfit.get("Sandwich Holder")
 mem.osd_title = _("The Last Detail")
 
 function create ()
@@ -58,12 +61,6 @@ function create ()
       misn.finish(false)
    end
 
-   misn.setNPC(_("Arnold Smith"), "neutral/unique/arnoldsmith.webp", _([[Perhaps it would be worthwhile to see if he has another job for you.]]))
-end
-
-function accept()
-   mem.stage = 0
-
    --Initialization of dead pirate memory
    mem.gawdead = false
    mem.kerdead1 = false
@@ -76,46 +73,85 @@ function accept()
    mem.kername2 = fmt.f( _("{name} Jr." ), {name=pilotname.pirate()} )
    mem.godname = fmt.f( _("{name} II"), {name=pilotname.pirate()} )
 
-   if tk.yesno(_("The mission"), _([["Hello again. As you know, I've agreed with the FLF on a contract that will extend our sales of ships to them substantially. Of course, this deal must remain a secret, which is why it is being done through a false black market dealer.
-    "However, we have reason to suspect that a few key influential pirates may have their eyes on the FLF as possible buyers of the Skull & Bones pirate ships. We don't think the FLF will have any interest in those ships, but the pirates' ambitions could give them motivation to attack our false dealer's trade posts, destroying our deal with the FLF anyway. We, of course, can't have that.
-    "So what we want you to do, quite simply, is to eliminate these pirates. There's not that many of them; there are four pirates we need eliminated, and thankfully, they're all spread out. That being said, some of them do have quite big ships, so you will have to make sure you can handle that. Are you willing to do this job for us?"]])) then
-      misn.accept()
-      tk.msg(_("Very good"), fmt.f(_([["So, here are the details we have gathered about these pirates:
-    "{gawname} should be in {gawsys}, flying a Gawain. He seems to be on a holiday, so he probably isn't able to fight back and will just run away.
-    "{kername1} should be in {kersys1}, flying a Kestrel. We believe he has some escorts.
-    "{kername2} should be in {kersys2}, also flying a Kestrel. He has escorts, too, according to our records.
-    "And finally, {godname} is in {godsys}. He stole and beefed up a Goddard recently, so make sure you're prepared for that. He also has escorts, according to our records.
-    "And that's about it! Come back for your fee when you have finished."]]), {gawname=mem.gawname, gawsys=mem.gawsys, kername1=mem.kername1, kersys1=mem.kersys1, kername2=mem.kername2, kersys2=mem.kersys2, godname=mem.godname, godsys=mem.godsys}))
+   misn.setNPC(shark.arnold.name, shark.arnold.portrait, _([[Perhaps it would be worthwhile to see if he has another job for you.]]))
+end
 
-      misn.setTitle(_("The Last Detail"))
-      misn.setReward(fmt.credits(shark.rewards.sh07))
-      misn.setDesc(_("Nexus Shipyards has tasked you with killing four pirates."))
-      misn.osdCreate(mem.osd_title, {
-         _("Kill the four pirates"),
-         fmt.f(_("Report back to {pnt} in {sys}"), {pnt=paypla, sys=paysys}),
-      })
-      misn.osdActive(1)
+function accept()
+   mem.stage = 0
 
-      mem.gawmarker = misn.markerAdd(mem.gawsys, "low")
-      mem.kermarker1 = misn.markerAdd(mem.kersys1, "high")
-      mem.kermarker2 = misn.markerAdd(mem.kersys2, "high")
-      mem.godmarker = misn.markerAdd(mem.godsys, "high")
+   local accepted = false
 
-      hook.enter("enter")
-      hook.land("land")
-   else
-      tk.msg(_("Sorry, not interested"), _([["I'm sorry to hear that. Don't hesitate to come back if you change your mind."]]))
-   end
+   vn.clear()
+   vn.scene()
+   local arnold = vn.newCharacter( shark.vn_arnold() )
+   vn.transition( shark.arnold.transition )
+
+   arnold(_([["Hello again. As you know, I've agreed with the FLF on a contract that will extend our sales of ships to them substantially. Of course, this deal must remain a secret, which is why it is being done through a false black market dealer.]]))
+   arnold(_([["However, we have reason to suspect that a few key influential pirates may have their eyes on the FLF as possible buyers of the Skull & Bones pirate ships. We don't think the FLF will have any interest in those ships, but the pirates' ambitions could give them motivation to attack our false dealer's trade posts, destroying our deal with the FLF anyway. We, of course, can't have that."]]))
+   arnold(_([["So what we want you to do, quite simply, is to eliminate these pirates. There's not that many of them; there are four pirates we need eliminated, and thankfully, they're all spread out. That being said, some of them do have quite big ships, so you will have to make sure you can handle that. Are you willing to do this job for us?"]]))
+   vn.menu{
+      {_([[Accept]]), "accept"},
+      {_([[Decline]]), "decline"},
+   }
+
+   vn.label("decline")
+   arnold(_([["I'm sorry to hear that. Don't hesitate to come back if you change your mind."]]))
+   vn.done( shark.arnold.transition )
+
+   vn.label("accept")
+   vn.func( function () accepted = true end )
+   arnold(fmt.f(_([["So, here are the details we have gathered about these pirates:
+"{gawname} should be in {gawsys}, flying a Gawain. He seems to be on a holiday, so he probably isn't able to fight back and will just run away.
+"{kername1} should be in {kersys1}, flying a Kestrel. We believe he has some escorts.
+"{kername2} should be in {kersys2}, also flying a Kestrel. He has escorts, too, according to our records.
+"And finally, {godname} is in {godsys}. He stole and beefed up a Goddard recently, so make sure you're prepared for that. He also has escorts, according to our records.
+"And that's about it! Come back for your fee when you have finished."]]),
+      {gawname=mem.gawname, gawsys=mem.gawsys, kername1=mem.kername1, kersys1=mem.kersys1, kername2=mem.kername2, kersys2=mem.kersys2, godname=mem.godname, godsys=mem.godsys}))
+
+   vn.done( shark.arnold.transition )
+   vn.run()
+
+   if not accepted then return end
+
+   misn.accept()
+
+   misn.setTitle(_("The Last Detail"))
+   misn.setReward(shark.rewards.sh07)
+   misn.setDesc(_("Nexus Shipyards has tasked you with killing four pirates."))
+   misn.osdCreate(mem.osd_title, {
+      _("Kill the four pirates"),
+      fmt.f(_("Report back to {pnt} in {sys}"), {pnt=paypla, sys=paysys}),
+   })
+   misn.osdActive(1)
+
+   mem.gawmarker = misn.markerAdd(mem.gawsys, "low")
+   mem.kermarker1 = misn.markerAdd(mem.kersys1, "high")
+   mem.kermarker2 = misn.markerAdd(mem.kersys2, "high")
+   mem.godmarker = misn.markerAdd(mem.godsys, "high")
+
+   hook.enter("enter")
+   hook.land("land")
 end
 
 function land ()
    --Job is done
    if mem.stage == 1 and spob.cur() == paypla then
-      tk.msg(_("That was impressive"), _([[Smith awaits your arrival at the spaceport. When you exit your ship, he smiles and walks up to you. "Good job," he says. "Our deal is secure, thanks to you. Here is your pay and something extra for your hard work. Thank you for all your help!"
-    He hands you a credit chip and what appears to be a Nexus Shipyards commemorative sandwich holder.]]))
-      pir.reputationNormalMission(rnd.rnd(2,3))
-      player.pay(shark.rewards.sh07)
-      player.outfitAdd("Sandwich Holder")
+      vn.clear()
+      vn.scene()
+      local arnold = vn.newCharacter( shark.vn_arnold() )
+      vn.transition( shark.arnold.transition )
+      arnold(_([[Smith awaits your arrival at the spaceport. When you exit your ship, he smiles and walks up to you. "Good job," he says. "Our deal is secure, thanks to you. Here is your pay and something extra for your hard work. Thank you for all your help!"
+He hands you a credit chip and what appears to be a Nexus Shipyards commemorative sandwich holder.]]))
+      vn.func( function ()
+         pir.reputationNormalMission(rnd.rnd(2,3))
+         player.pay(shark.rewards.sh07)
+         player.outfitAdd(reward_outfit)
+      end )
+      vn.sfxVictory()
+      vn.na(fmt.reward(shark.rewards.sh07).."\n"..fmt.reward(reward_outfit))
+      vn.done( shark.arnold.transition )
+      vn.run()
+
       shark.addLog( _([[You eliminated some pirates that were about to get in the way of Nexus Shipyards' business.]]) )
       misn.finish(true)
    end
@@ -250,7 +286,7 @@ end
 function generic_dead()
    --Are there still other pirates to kill ?
    if mem.gawdead == true and mem.kerdead1 == true and mem.kerdead2 == true and mem.goddead == true then
-      tk.msg(_("Mission accomplished"), fmt.f(_([[You have killed the four pirates. Now to return to {sys} and collect your payment...]]), {sys=paysys}))
+      vntk.msg(_("Mission accomplished"), fmt.f(_([[You have killed the four pirates. Now to return to {sys} and collect your payment…]]), {sys=paysys}))
       mem.stage = 1
       misn.osdActive(2)
       mem.marker2 = misn.markerAdd(paypla, "low")
@@ -258,5 +294,5 @@ function generic_dead()
 end
 
 function generic_jumped()
-   tk.msg(_("Target is gone!"), _([[It seems the pirate left. Don't worry: I'll bet that if you come back a little later, they will be back.]]))
+   vntk.msg(_("Target is gone!"), _([[It seems the pirate left. Don't worry: I'll bet that if you come back a little later, they will be back.]]))
 end
