@@ -78,7 +78,7 @@ function create ()
    misn.setTitle( title )
    misn.setDesc(fmt.f(_("You have been asked to help find {name}, who went missing."),
       {name = taiomi.young_died()} ) )
-   misn.setReward( fmt.credits(reward) )
+   misn.setReward(reward)
    mem.marker = misn.markerAdd( base )
 
    misn.osdCreate( title, {
@@ -462,6 +462,7 @@ function land ()
       local w = taiomi.vn_elder{ pos="farleft", flip=true }
       local sai = tut.vn_shipai()
       local died = taiomi.young_died()
+      vn.transition()
 
       vn.na(fmt.f(_("You return to the {base} to try to process what happened… Not only was the life of {dead} lost, but Scavenger has also gone missing in their thirst for revenge…"),
          {base=base, dead=taiomi.young_died()}))
