@@ -5,6 +5,9 @@
  <chance>0</chance>
  <location>None</location>
  <done>Taiomi 9</done>
+ <tags>
+  <tag>fleetcap_10</tag>
+ </tags>
  <notes>
   <campaign>Taiomi</campaign>
  </notes>
@@ -193,6 +196,7 @@ function enter ()
    hypergate = pilot.add( "One-Wing Goddard", "Independent", bpos, nil, {naked=true, ai="dummy"} )
    hypergate:disable()
    hypergate:setHilight(true)
+   hypergate:setNoBoard(true)
    hook.pilot( hypergate, "death", "hypergate_dead" )
 
    local sdrone = ship.get("Drone")
@@ -550,7 +554,7 @@ Protocols don't cover this. What should we do?]]))
    l2g(_([[…]]))
    log(_([[ …]]),true)
    log(_([[ …]]),true)
-   vne.flashbackTextEnd( true, "blur", 3 )
+   vne.flashbackTextEnd{ done=true, transition="blur", transition_length=3 }
    vn.run()
    music.stop()
 
@@ -658,7 +662,7 @@ Erk…"]]))
 
    vn.label("cont01")
    d(_([["I… I'm having trouble remembering anything…"]]))
-   vn.na(fmt.f(_([[{shipai} plays a partially incomplete recording of the battle in the {sys} system and subsequent potentially activation of the hypergate. Scavenger seems to be digesting the information.]]),
+   vn.na(fmt.f(_([[{shipai} plays a partially incomplete recording of the battle in the {sys} system and subsequent potential activation of the hypergate. Scavenger seems to be digesting the information.]]),
       {shipai=tut.ainame(), sys=basesys}))
    d(_([["Let me try to do a probabilistic reconstruction of the events. I believe the hypergate malfunctioned, no wait, due to the attack, I was not able to fully install the activation protocols on your ship."]]))
    d(_([["The hypergate failed to activate due to subspace instabilities and sustained damage. I believe I salvaged the situation by staying behind and activating it myself."]]))
