@@ -104,7 +104,7 @@ function create ()
 
    misn.setTitle( _("Helping Nelly Out") )
    misn.setDesc( fmt.f(_("Help Nelly deliver {tonnes} of {cargo} to {destpnt} in the {destsys} system."), {tonnes=fmt.tonnes(cargo_q), cargo=cargo_type, destpnt=mem.destpnt, destsys=mem.destsys} ))
-   misn.setReward( fmt.credits(reward_amount) )
+   misn.setReward(reward_amount)
 end
 
 
@@ -117,11 +117,11 @@ function accept ()
 
    if var.peek("nelly_met") then
       nel(fmt.f(_([[Nelly lightens up when you near her.
-"Hello again! I'm in a bit of a mess. You see, I was supposed to deliver some {cargo} to {pnt} in the {sys} system, but my ship broke down and I don't think I'll be able to deliver it any time soon. Would you be willing to help me take the cargo there and come back? I'll pay you your fair share."]]),
+"Hello again! I'm in a bit of a mess. You see, I was supposed to deliver some {cargo} to {pnt} in the {sys} system, but my ship broke down, and I don't think I'll be able to deliver it any time soon. Would you be willing to help me take the cargo there and come back? I'll pay you your fair share."]]),
          {cargo=cargo_type, pnt=mem.destpnt, sys=mem.destsys}))
    else
       nel(fmt.f(_([[The lone individual lightens up when you near her.
-"Say, you look like a pilot with a working ship. I'm in a bit of a mess. You see, I was supposed to deliver some {cargo} to {pnt} in the {sys} system, but my ship broke down and I don't think I'll be able to deliver it any time soon. Would you be willing to help me take the cargo there and come back? I'll pay you your fair share."]]),
+"Say, you look like a pilot with a working ship. I'm in a bit of a mess. You see, I was supposed to deliver some {cargo} to {pnt} in the {sys} system, but my ship broke down, and I don't think I'll be able to deliver it any time soon. Would you be willing to help me take the cargo there and come back? I'll pay you your fair share."]]),
          {cargo=cargo_type, pnt=mem.destpnt, sys=mem.destsys}))
    end
 
@@ -149,9 +149,9 @@ function accept ()
       doaccept = true
    end )
    if var.peek("nelly_met") then
-      nel(_([["Great! I'll have the dock workers load up your ship and we can be off. This should be a piece of cake."]]))
+      nel(_([["Great! I'll have the dockworkers load up your ship, and we can be off. This should be a piece of cake."]]))
    else
-      nel(_([["Great! My name is Nelly. Glad to make your acquaintance. I'll have the dock workers load up your ship and we can be off. This should be a piece of cake."
+      nel(_([["Great! My name is Nelly. Glad to make your acquaintance. I'll have the dockworkers load up your ship, and we can be off. This should be a piece of cake."
    They cock their head a bit at you.
    "Say, you wouldn't happen to be a novice pilot?"]]))
       vn.func( function ()
@@ -231,8 +231,6 @@ function land ()
       vn.done( tutnel.nelly.transition )
       vn.run()
 
-      player.pay( outfit_tobuy:price() )
-
       -- Get rid of cargo
       misn.cargoRm( mem.cargo_id )
       mem.misn_state = 2
@@ -299,7 +297,7 @@ function enter ()
       vn.scene()
       local nel = vn.newCharacter( tutnel.vn_nelly() )
       vn.transition( tutnel.nelly.transition )
-      vn.na(fmt.f(_("After the dock workers load the cargo on your ship, you take off with Nelly aboard. On to {sys}!"), {sys=mem.destsys}))
+      vn.na(fmt.f(_("After the dockworkers load the cargo on your ship, you take off with Nelly aboard. On to {sys}!"), {sys=mem.destsys}))
       nel(_([[Just after taking off Nelly pipes up.
 "Say, are you familiar with the information window? It shows all the important things about your ship and current missions."]]))
       vn.menu{
@@ -324,12 +322,12 @@ function enter ()
       mem.misn_state = 1
 
    elseif mem.misn_state==2 and system.cur() == mem.retsys then
-      hook.timer( 5e3, "talk_derelict" )
+      hook.timer( 5, "talk_derelict" )
 
       local pos = player.pos() * 0.6 -- Should be to the center of the system
-      derelict = pilot.add( "Koala", "Derelict", pos, _("Derelict") )
+      derelict = pilot.add( "Koala", "Derelict", pos, p_("ship", "Derelict") )
       derelict:disable()
-      derelict:intrinsicSet( "ew_hide", -75 ) -- Much more visible
+      derelict:intrinsicSet( "ew_hide", 300 ) -- Much more visible
       derelict:setHilight(true)
       hook.pilot( derelict, "board", "board" )
 
@@ -344,7 +342,7 @@ function talk_derelict ()
    vn.transition( tutnel.nelly.transition )
    vn.na(_([[After you enter the system, Nelly points something out on the radar.]]))
    -- TODO autoboard!
-   nel(fmt.f(_([["Oooh, look at that. A Koala derelict is nearby. There might be something interesting on it! We should go board it. Try #odouble-click#0ing or selecting the derelict and pressing {boardkey}. It should enable your autonav system to board the ship. You can toggle the overlay to see exactly where the ship is with {overlaykey}."]]),{boardkey=tut.getKey("board"), overlaykey=tut.get("overlay")}))
+   nel(fmt.f(_([["Oooh, look at that. A Koala derelict is nearby. There might be something interesting on it! We should go board it. Try #odouble-click#0ing or selecting the derelict and pressing {boardkey}. It should enable your autonav system to board the ship. You can toggle the overlay to see exactly where the ship is with {overlaykey}."]]),{boardkey=tut.getKey("approach"), overlaykey=tut.getKey("overlay")}))
    vn.done( tutnel.nelly.transition )
    vn.run()
 end
@@ -354,6 +352,7 @@ function board ()
    vn.clear()
    vn.scene()
    local nel = tutnel.vn_nelly()
+   vn.transition( tutnel.nelly.transition )
    vn.na(_([[You enter the derelict ship which is eerily silent. A large hole in the engine room indicates that likely the core engine blew out, forcing the ship crew to abandon ship. Although you don't find anything of significant value, there is still lots of ore cargo available on the ship. You quickly load as much as you can onto your ship before you depart.]]))
    vn.appear( nel )
    nel(fmt.f(_([["Looks like your scored a lot of ore there. That should bring you a pretty penny at a planet with commodity exchange. Boarding derelicts is not always as easy as this and sometimes bad things can happen. We should head to {pnt} that should be nearby now."]]), {pnt=mem.retpnt}))
@@ -391,7 +390,7 @@ function info ()
       mem.hk_info = nil
    end
 
-   info_msg( _([["Ah, the info menu in all it's glory. In the main window, you can see overall statistics of your gameplay and license information. Try to navigate to the #oMissions#0 tab. Feel free to click the other tabs for more information."]]) )
+   info_msg( _([["Ah, the info menu in all its glory. In the main window, you can see overall statistics of your gameplay and license information. Try to navigate to the #oMissions#0 tab. Feel free to click the other tabs for more information."]]) )
 
    mem.hk_info_ship      = hook.info( "info_ship",     "ship" )
    mem.hk_info_weapons   = hook.info( "info_weapons",  "weapons" )
@@ -422,9 +421,10 @@ end
 
 function info_weapons ()
    info_msg( fmt.f(_([["At the #oWeapon Info#0, you can modify the current ship's weapon sets. There are three types of weapon sets:
-- #oWeapons - Switched#0: when activated define the weapons you should with the primary weapon key {keyprimary} and secondary weapon key {keysecondary}.
-- #oWeapons - Instant#0: immediately fires the weapon set weapons when the set hotkey is pressed. Enable this for a set by checking the #oEnable instant mode#0 checkbox.
-- #oAbilities - Toggled#0: toggles the state of the non-weapon outfits in the set."]]), {keyprimary=tut.getKey("primary"), keysecondary=tut.getKey("secondary")} ) )
+- #oSwitch#0: sets which weapons fire with the primary weapon key {keyprimary} and secondary weapon key {keysecondary}.
+- #oToggle#0: toggles the state between on and off of the outfits in the sets.
+- #oHold#0: turns on all the outfits in the set while held down."]]),
+      {keyprimary=tut.getKey("primary"), keysecondary=tut.getKey("secondary")} ) )
    hook.rm( mem.hk_info_weapons )
    mem.hk_info_weapons = nil
    info_checkdone()
@@ -488,8 +488,7 @@ function outfits ()
    mem.hk_land_outfits = nil
 end
 
-function outfit_buy( name, _q )
-   local o = outfit.get( name )
+function outfit_buy( o, _q )
    local t = o:type()
    if t=="Map" or t=="Local Map" or t=="License" or t=="GUI" or t=="Unknown" then
       return
@@ -508,7 +507,7 @@ function outfit_buy( name, _q )
 end
 
 function equipment ()
-   info_msg( fmt.f(_([["The #oEquipment Tab#0 allows to handle your ships and their equipment. You can have more than one ship and switch between them freely. Try to equip the #o{outfit}#0 in a weapon slot by first clicking on the outfit and then right clicking on the slot you want to equip it at. If you have free slots you can also right click on an outfit to have it directly be assigned to the smallest free slot it fits into. Try to equip the #o{outfit}#0 now."]]), {outfit=outfit_tobuy}) )
+   info_msg( fmt.f(_([["The #oEquipment Tab#0 allows handling your ships and their equipment. You can have more than one ship and switch between them freely. Try to equip the #o{outfit}#0 in a weapon slot by first clicking on the outfit and then right-clicking on the slot you want to equip it at. If you have free slots you can also right-click on an outfit to have it directly be assigned to the smallest free slot it fits into. Try to equip the #o{outfit}#0 now."]]), {outfit=outfit_tobuy}) )
 
    mem.hk_equip = hook.equip( "equip" )
 end
