@@ -102,7 +102,7 @@ OK, maybe a little. Let's get going!"]]))
 
    -- mission details
    misn.setTitle( title )
-   misn.setReward( fmt.credits(reward) )
+   misn.setReward(reward)
    misn.setDesc(fmt.f(_("Investigate the mysterious signal coming from the {sys} system with Zach."),{sys=insys}))
 
    local c = commodity.new( N_("Zach"), N_("A Za'lek scientist.") )
@@ -152,7 +152,7 @@ local function icarus_talk ()
    z(_([["It looks like there's been a misunderstanding. Could this be from where Icarus came from? I have no idea where we are, but the rough coordinates seem to indicate we are near Soromid space."]]))
    i(_([["Elders. Ahaeosrc."
 The translation system struggles with what Icarus is saying.]]))
-   z(_([["Mmmm, this seems to be a word that wasn't in the original notes. I'm not sure we're going to be able to translate it."]]))
+   z(_([["Mmmm, this seems to be a word that wasn't in the original notes. I'm not sure how we're going to be able to translate it."]]))
    i(_([["Ahaeosrc. Zach."]]))
    z(_([["Wait, what? How did my name get picked up in the translation system?… Does this mean that…"
 He goes silent, lost in thought.]]))
@@ -197,13 +197,13 @@ function enter ()
 
    elseif mem.state==2 and system.cur() == mainsys then
       local p = pilot.add( "Za'lek Scout Drone", zbh.evilpi(), mainpnt:pos(), nil, {ai="baddie"} )
-      p:intrinsicSet( "ew_hide", -50 ) -- Easier to spot
+      p:intrinsicSet( "ew_hide", 100 ) -- Easier to spot
       p:control(true)
       p:stealth()
       hook.pilot( p, "discovered", "scout_discovered" )
 
    elseif mem.state==1 and system.cur() == insys then
-      player.allowLand( false, _("Zach is analyzing the wormhole signal.") )
+      player.landAllow( false, _("Zach is analyzing the wormhole signal.") )
 
       if mem.wormholeknown then
          system.markerAdd( inwormhole:pos(), _("Wormhole") )
@@ -219,7 +219,7 @@ function enter ()
       pilot.clear()
       pilot.toggleSpawn(false)
 
-      player.allowLand( false, _("The wormhole seems to have become too weak to go through.") )
+      player.landAllow( false, _("The wormhole seems to have become too weak to go through.") )
 
       --local j = jump.get( outsys, "NGC-4771" )
       local pp = player.pilot()
@@ -251,7 +251,7 @@ function enter ()
       hook.timer( 18, "heartbeat_ferals" )
 
    elseif mem.state == 2 and system.cur() == mainsys then
-      hook.timer( 15, "zach_say", _("It's a bit quiet without Icarus around anymore…") )
+      hook.timer( 15, "zach_say", _("It's a bit quiet without Icarus around any more…") )
 
    end
 end
@@ -302,7 +302,7 @@ function heartbeat_wormhole ()
       local msg = msglist[ wstate-2 ]
       zach_say( msg )
       if msglist[ wstate-1 ]==nil then -- Was the last message
-         player.allowLand()
+         player.landAllow()
          misn.osdCreate( title, { _("Go through the wormhole") } )
          return
       end
@@ -455,7 +455,7 @@ function heartbeat_ferals ()
 
    elseif fstate == 11 and icarus:pos():dist( player.pos() ) < 3000 then
       local pp = player.pilot()
-      player.allowLand()
+      player.landAllow()
       pp:setNoJump(false)
 
       pp:control()
@@ -491,10 +491,12 @@ function heartbeat_ferals ()
          icarus:face( l )
 
          for k,p in ipairs(pack) do
-            p:setInvisible(false)
-            p:taskClear()
-            p:brake()
-            p:face( icarus )
+            if p:exists() then
+               p:setInvisible(false)
+               p:taskClear()
+               p:brake()
+               p:face( icarus )
+            end
          end
 
          nexttime = 3
