@@ -6,7 +6,16 @@
  <chance>30</chance>
  <faction>Za'lek</faction>
  <location>Bar</location>
- <cond>spob.cur() ~= spob.get("Katar I") and faction.playerStanding("Za'lek") &gt;= 0</cond>
+ <cond>
+   if spob.cur() == spob.get("Katar I") then
+      return false
+   end
+   if faction.playerStanding("Za'lek") &lt; 0 then
+      return false
+   end
+   --return require("misn_test").reweight_active() -- Don't reweight since license are important
+   return true
+ </cond>
  <notes>
   <campaign>Za'lek Particle Physics</campaign>
   <tier>1</tier>
@@ -86,7 +95,7 @@ That doesn't sound very reassuring.
 
    -- mission details
    misn.setTitle( _("Particle Physics") )
-   misn.setReward( fmt.credits(reward) )
+   misn.setReward(reward)
    misn.setDesc( fmt.f(_("Take Noona and some equipment to {pnt} in the {sys} system."), {pnt=destpnt, sys=destsys} ))
 
    misn.markerAdd( destpnt )
