@@ -1,7 +1,7 @@
 local active = 4 -- active time in seconds
 local cooldown = 8 -- cooldown time in seconds
 local boost = 5 -- How much the shield regen is increased by
-local efficiency = 3 -- MJ of energy used per shield recovered
+local efficiency = 3 -- GJ of energy used per shield recovered
 
 local function turnon( p, po )
    -- Still on cooldown
