@@ -24,10 +24,29 @@ end
    value indicating the amount of credits to refund the player.
 --]]
 local outfit_list = {
+   -- Below is a list of changes from 0.10.0 to 0.11.0
+   ["Unicorp D-68 Heavy Plating"] = "Unicorp D-72 Heavy Plating",
+   ["Unicorp D-48 Heavy Plating"] = "Unicorp D-58 Heavy Plating",
+   ["Unicorp D-24 Medium Plating"] = "Unicorp D-38 Medium Plating",
+   ["Unicorp D-12 Medium Plating"] = "Unicorp D-23 Medium Plating",
+   ["Unicorp D-4 Light Plating"] = "Unicorp D-9 Light Plating",
+   ["Unicorp Eagle 7000 Engine"] = "Unicorp Eagle 6500 Engine",
+   ["Nexus Bolt 3500 Engine"] = "Nexus Bolt 3000 Engine",
+   ["Unicorp Falcon 1300 Engine"] = "Unicorp Falcon 1400 Engine",
+   ["Unicorp Hawk 350 Engine"] = "Unicorp Hawk 360 Engine",
+   ["Nexus Dart 150 Engine"] = "Nexus Dart 160 Engine",
+   ["Razor MK1"] = "Razor Artillery S1",
+   ["Razor MK2"] = "Razor Artillery S2",
+   ["Slicer"] = "Razor Artillery S3",
+   ["Razor Turret MK1"] = 50e3,
+   ["Razor Turret MK2"] = "Razor Battery S2",
+   ["Tesla Cannon"] = 780e3,
+   ["Heavy Razor Turret"] = "Disruptor Battery S2",
+   ["Fidelity Bay"] = "Sirius Fidelity Bay",
    -- Below is a list of changes from 0.9.0 to 0.10.0
    ["Drone Fighter Bay"] = "Drone Bay",
    ["Empire Lancelot Fighter Bay"] = "Empire Lancelot Bay",
-   ["Fidelity Fighter Bay"] = "Fidelity Bay",
+   --["Fidelity Fighter Bay"] = "Fidelity Bay",
    ["Hyena Fighter Dock"] = "Hyena Bay",
    ["Hyena Fighter Bay"] = "Hyena Dock",
    ["Lancelot Fighter Bay"] = "Lancelot Bay",
@@ -355,20 +374,20 @@ local outfit_list = {
    ["Unicorp PT-600 Core System"] = "Unicorp PT-310 Core System",
    ["Unicorp PT-1000 Core System"] = "Unicorp PT-2200 Core System",
    ["Unicorp PT-100 Core System"] = "Unicorp PT-16 Core System",
-   ["Unicorp Hawk 150 Engine"] = "Nexus Dart 150 Engine",
-   ["Unicorp Falcon 550 Engine"] = "Unicorp Falcon 1300 Engine",
-   ["Unicorp Falcon 1200 Engine"] = "Unicorp Falcon 1300 Engine",
-   ["Unicorp Eagle 6500 Engine"] = "Unicorp Eagle 7000 Engine",
-   ["Unicorp Eagle 4500 Engine"] = "Unicorp Eagle 7000 Engine",
-   ["Unicorp D-8 Medium Plating"] = "Unicorp D-12 Medium Plating",
-   ["Unicorp D-20 Heavy Plating"] = "Unicorp D-68 Heavy Plating",
-   ["Unicorp D-16 Heavy Plating"] = "Unicorp D-68 Heavy Plating",
-   ["Unicorp B-8 Medium Plating"] = "Unicorp D-12 Medium Plating",
-   ["Unicorp B-4 Light Plating"] = "Unicorp D-4 Light Plating",
-   ["Unicorp B-20 Heavy Plating"] = "Unicorp D-68 Heavy Plating",
+   ["Unicorp Hawk 150 Engine"] = "Nexus Dart 160 Engine", -- Modified for 0.11.0
+   ["Unicorp Falcon 550 Engine"] = "Unicorp Falcon 1400 Engine",
+   ["Unicorp Falcon 1200 Engine"] = "Unicorp Falcon 1400 Engine",
+   ["Unicorp Eagle 6500 Engine"] = "Unicorp Eagle 6500 Engine",
+   ["Unicorp Eagle 4500 Engine"] = "Unicorp Eagle 6500 Engine",
+   ["Unicorp D-8 Medium Plating"] = "Unicorp D-23 Medium Plating",
+   ["Unicorp D-20 Heavy Plating"] = "Unicorp D-72 Heavy Plating",
+   ["Unicorp D-16 Heavy Plating"] = "Unicorp D-72 Heavy Plating",
+   ["Unicorp B-8 Medium Plating"] = "Unicorp D-23 Medium Plating",
+   ["Unicorp B-4 Light Plating"] = "Unicorp D-9 Light Plating",
+   ["Unicorp B-20 Heavy Plating"] = "Unicorp D-72 Heavy Plating",
    ["Unicorp B-2 Light Plating"] = "Unicorp D-2 Light Plating",
-   ["Unicorp B-16 Heavy Plating"] = "Unicorp D-24 Medium Plating",
-   ["Unicorp B-12 Medium Plating"] = "Unicorp D-24 Medium Plating",
+   ["Unicorp B-16 Heavy Plating"] = "Unicorp D-38 Medium Plating",
+   ["Unicorp B-12 Medium Plating"] = "Unicorp D-38 Medium Plating",
    ["Thurion Reactor Class III"] = 155e4,
    ["Thurion Reactor Class II"] = 97e4,
    ["Thurion Reactor Class I"] = 53e4,
@@ -385,8 +404,8 @@ local outfit_list = {
    ["S&K Medium-Heavy Stealth Plating"] = 48e4,
    ["S&K Medium Stealth Plating"] = 27e4,
    ["S&K Light Stealth Plating"] = 18e4,
-   ["Razor Turret MK3"] = "Razor Turret MK1",
-   ["Razor MK3"] = "Razor MK1",
+   ["Razor Turret MK3"] = 50e3, -- "Razor Turret MK1",
+   ["Razor MK3"] = "Razor Artillery S1", -- "Razor MK1",
    ["Pulse Beam"] = 26e3,
    ["Power Regulation Override"] = 55e3,
    ["Plasma Cluster Cannon MK3"] = "Plasma Cluster Cannon",
@@ -395,9 +414,9 @@ local outfit_list = {
    ["Plasma Blaster MK3"] = 26e3,
    ["Plasma Blaster MK2"] = 17e3,
    ["Plasma Blaster MK1"] = 9e3,
-   ["Nexus Dart 300 Engine"] = "Nexus Dart 150 Engine",
-   ["Nexus Bolt 6500 Engine"] = "Nexus Bolt 3500 Engine",
-   ["Nexus Bolt 4500 Engine"] = "Nexus Bolt 3500 Engine",
+   ["Nexus Dart 300 Engine"] = "Nexus Dart 160 Engine", -- Modified for 0.11.0
+   ["Nexus Bolt 6500 Engine"] = "Nexus Bolt 3000 Engine",
+   ["Nexus Bolt 4500 Engine"] = "Nexus Bolt 3000 Engine",
    ["Nexus Arrow 550 Engine"] = "Nexus Arrow 700 Engine",
    ["Nexus Arrow 1200 Engine"] = "Nexus Arrow 700 Engine",
    ["Milspec Prometheus 9803 Core System"] = "Milspec Thalos 9802 Core System",
