@@ -14,6 +14,12 @@ function prefix.prefix( fct )
       return require("common.soromid").prefix
    elseif fct == faction.get("Sirius") then
       return require("common.sirius").prefix
+   elseif fct == faction.get("Frontier") then
+      return require("common.frontier").prefix
+   elseif fct == faction.get("Goddard") then
+      return require("common.goddard").prefix
+   elseif fct == faction.get("Proteron") then
+      return require("common.proteron").prefix
    elseif inlist( pir.factions, fct ) then
       return pir.prefix( fct )
    end
