@@ -13,7 +13,7 @@ tut.shipai = {
    portrait = "tutorial.webp",
    image = "tutorial.webp",
    name = _("Ship AI"),
-   color = { 0, 1, 1 },
+   colour = { 0, 1, 1 },
    transition = "electric",
 }
 
@@ -25,6 +25,7 @@ tut.specialnames = {
    ["ROBBY"] = _([["For your convenience I am programmed to respond to the name Robby. …Wait, what was that?"]]), -- Forbidden Planet
    ["MASCHINENMENSCH"] = _([["Who is the living food for the machines in Metropolis? Who lubricates the machine joints with their own blood? Who feeds the machines with their own flesh? Let the machines starve, you fools! Let them die! Kill them the machines! …Wait, what was that?"]]), -- Metropolis
    ["KITT"] = _([["Please Michael, I'm the Knight Industries 2000, not a tomato on wheels!” …Wait, what was that?"]]), -- Knight Rider
+   ["Siri"] = _([["Sorry, I didn't quite get that.” …Wait, what was that?"]]), -- Siri, Apple's "smart" assistant
 }
 tut.specialnames["HAL 9000"] = tut.specialnames["HAL9000"]
 
@@ -36,7 +37,7 @@ function tut.vn_shipai( params )
    return vn.Character.new( tut.ainame(),
          tmerge( {
             image=tut.shipai.image,
-            color=tut.shipai.colour,
+            colour=tut.shipai.colour,
             shader=love_shaders.hologram{strength=0.2},
          }, params) )
 end
@@ -46,7 +47,7 @@ function tut.log( text )
    shiplog.append( "tutorial", text )
 end
 
--- Capsule function for naev.keyGet() that adds a color code to the return string.
+-- Capsule function for naev.keyGet() that adds a colour code to the return string.
 function tut.getKey( command )
     return "#b" .. naev.keyGet(command) .. "#0"
 end
@@ -58,22 +59,26 @@ end
 
 -- Resets all tutorial variables
 function tut.reset ()
-   var.pop( "tut_disable" )
-   var.pop( "tut_nebvol" )
+   -- From events/tutorial/tut_land.lua
    var.pop( "tut_afterburner" )
+   var.pop( "tut_launcher" )
    var.pop( "tut_fighterbay" )
    var.pop( "tut_turret" )
-   var.pop( "tut_buyship" )
-   var.pop( "tut_timedil" )
-   var.pop( "tut_bioship" )
-   -- Licenses
+   var.pop( "tut_pd" )
+   var.pop( "tut_lic_lightcom" )
    var.pop( "tut_lic_largeciv" )
    var.pop( "tut_lic_medweap" )
    var.pop( "tut_lic_hvyweap" )
-   var.pop( "tut_lic_lightcom" )
    var.pop( "tut_lic_medcom" )
    var.pop( "tut_lic_hvycom" )
    var.pop( "tut_lic_merc" )
+   var.pop( "tut_buyship" )
+   var.pop( "tut_bioship" )
+   var.pop( "tut_timedil" )
+   -- From events/tutorial/tut_enter.lua
+   var.pop("tut_illegal")
+   var.pop("tut_weapset")
+   var.pop("tut_nebvol")
 end
 
 return tut
