@@ -22,6 +22,8 @@ local soromid_outfits = eoutfits.merge{{
    "Plasma Cannon", "Plasma Turret MK1",
    "Plasma Blaster MK1", "Plasma Blaster MK2",
    "TeraCom Banshee Launcher", "TeraCom Mace Launcher",
+   -- Point Defense
+   "Spittle Tubuloid Cluster",
    -- Utility
    "Droid Repair Crew", "Milspec Scrambler",
    "Targeting Array", "Agility Combat AI",
@@ -77,7 +79,7 @@ local function equip_soromid( p, opt_params  )
    if sp then
       params = tmerge_r( params, sp() )
    end
-   params = tmerge( params, opt_params )
+   params = tmerge_r( params, opt_params )
 
    -- Outfits
    local outfits = soromid_outfits
