@@ -3,7 +3,7 @@ return {
    cap_kill       = 10,
    delta_distress = {-0.5, 0},    -- Maximum change constraints
    delta_kill     = {-5, 1},    -- Maximum change constraints
-   cap_misn_def   = 30,
+   cap_misn_def   = 70, --30, -- TODO lower as missions get added
    cap_misn_var   = "_fcap_sirius",
    cap_tags       = {
    },
