@@ -15,8 +15,8 @@ love.exec( 'pong' ) -- Will look for pong.lua or pong/main.lua
 love = {
    _basepath = "",
    _version_major = 11,
-   _version_minor = 1,
-   _version_patch = 3,
+   _version_minor = 4,
+   _version_patch = 0,
    _codename = "naev",
    _default = {
       title = "LÖVE",
@@ -100,6 +100,10 @@ function love.origin()
    local lg = require "love.graphics"
    lg.origin()
 end
+-- Non-standard function to refresh the screen
+function love.refresh ()
+   tk.refresh()
+end
 
 
 --[[
@@ -157,12 +161,12 @@ local function _mouse( x, y, mtype, button )
       return love.wheelmoved( x, y )
    end
 end
-local function _keyboard( pressed, key, _mod )
+local function _keyboard( pressed, key, _mod, isrepeat )
    if not love.keyboard then return false end
    local k = string.lower( key )
    love.keyboard._keystate[ k ] = pressed
    if pressed then
-      return love.keypressed( k, k, false )
+      return love.keypressed( k, k, isrepeat )
    else
       return love.keyreleased( k, k )
    end
@@ -272,7 +276,7 @@ function love.exec( path )
    end
    love._focus = true
    love._started = true
-   naev.tk.custom( love.title, love.w, love.h, _update, _draw, _keyboard, _mouse, _resize, _textinput )
+   naev.tk.custom( love.title, love.w, love.h, _update, _draw, _keyboard, _mouse, _resize, _textinput, t.drawondemand )
    -- Doesn't actually get here until the dialogue is closed
    love._started = false
 
