@@ -13,6 +13,7 @@ mem.params = {
       _([["Don't attempt to bribe an Empire official, pilot."]]),
    },
 }
+luaspob.setup( mem.params )
 
 local function initparams ()
    local std_land = 50
@@ -32,6 +33,3 @@ load = function ()
    initparams()
    return luaspob.load()
 end
-unload = luaspob.unload
-can_land = luaspob.can_land
-comm = luaspob.comm
